
cd "..\DATA"
use "employee_full_final", clear
cd "..\Tables"
*We established that we would not accept the responses of subjects who were too fast (timing below the 25% percentile – approximately 22 minutes) or too slow (timing above the 95% percentile – approximately 70 minutes) in completing the experiment.


gen emplye_min_dur=emplye_durationinseconds/60

su emplye_min_dur , det

drop if emplye_min_dur<21.76 

drop if  emplye_min_dur>69.93 


*We also excluded subjects who failed both attention checks, namely incorrectly stating their wage with an error of at least 5 tokens and misreporting their role (clerk or manager).


gen wrong_wage=(abs(emplye_guess_your_wage-emplye_wage)>2) 
gen wrong_wage2=(abs(emplye_guess_your_wage-emplye_wage)>5) 
replace wrong_wage2=0 if emplye_position=="Manager"


gen todrop3=(wrong_wage2==1 & emplye_misunderstood_position==1 )


drop if todrop3==1



************************************************************
************************************************************
*Renaming and creating variables
rename emplye_country country
encode country, gen (country_num)
encode emplye_maintaskresult, gen(pass)
rename pass passold
gen pass=passold-1
rename emplye_gender gender
ta gender, gen(female)
rename female1 female
rename emplye_treatment treatment
gen taskscore=emplye_maintaskscoreclerk
replace taskscore=emplye_maintaskscoremanager if emplye_maintaskscoreclerk==.
gen clerk=(emplye_maintaskscoreclerk!=.)
rename emplye_group group
gen manager=(clerk==0)
gen low_wage=(emplye_wage==150)
gen education=emplye_education
replace education=3 if education<=2
replace education=4 if education==5
replace education=education-2
replace education=3 if education==4
*In this paper we decided to merge the two treatments (T1 and T2) since they both introduced transparency in the experimental environment, and report results accordingly
gen wage_info=(treatment>0)
rename emplye_screeningtaskscore_2 screeningscore
rename  emplye_risk_taker  risk_taker
ta education, gen (edu)
gen age=2020-emplye_yearborn
gen number_female=emplye_number_female_manager+emplye_number_female_clerk
gen timer_clerk_min=substr(emplye_customtimer_mtc, 1,2)
gen timer_clerk_sec=substr(emplye_customtimer_mtc, 4,2)
destring timer_clerk_min timer_clerk_sec, replace
replace timer_clerk_min=timer_clerk_min*60
gen timer_clerk=timer_clerk_min+timer_clerk_sec
gen timer_manager_min=substr(emplye_customtimer_mtm, 1,2)
gen timer_manager_sec=substr(emplye_customtimer_mtm, 4,2)
destring timer_manager_min timer_manager_sec, replace
replace timer_manager_min=timer_manager_min*60
gen timer_manager=timer_manager_min+timer_manager_sec
gen stop=(taskscore==120 & timer_clerk!=0)
gen manager_stop=(taskscore==170  & timer_manager!=0)
replace stop =manager_stop if clerk==0
rename emplye_requestcompensation compensation 
gen transparencyXfemale=wage_info*female
gen merit_compensation=(low_wage==1 & group=="A" & emplye_average_wage_clerk!=150)
replace merit_compensation=1 if low_wage==1 & group=="B" & (emplye_mb_clerk_225==1|emplye_fb_clerk_225==1)
gen below_average_both=(emplye_wage<emplye_average_wage_male_clerk & emplye_wage<emplye_average_wage_female_clerk)
gen below_average_same=((emplye_wage<emplye_average_wage_male_clerk) & female==0 & (emplye_wage>=emplye_average_wage_female_clerk))
replace below_average_same=1 if (emplye_wage<emplye_average_wage_female_clerk) & female==1 & (emplye_wage>=emplye_average_wage_male_clerk)
gen below_average_opposite=((emplye_wage>=emplye_average_wage_male_clerk) & female==0 & (emplye_wage<emplye_average_wage_female_clerk))
replace below_average_opposite=1 if (emplye_wage>=emplye_average_wage_female_clerk) & female==1 & (emplye_wage<emplye_average_wage_male_clerk)
gen oppositeXtransparency=below_average_opposite*wage_info
gen samegenXtransparency=below_average_same*wage_info
gen bothXtransparency=below_average_both*wage_info
gen same_average=(emplye_average_wage_clerk==150)
gen below_average=(emplye_average_wage_clerk!=150 & low_wage==1)
gen above_average=(emplye_average_wage_clerk!=150 & low_wage==0)
gen aboveXtransparency=above_average*wage_info
gen belowXtransparency=below_average*wage_info
gen sameXtransparency=same_average*wage_info


label var taskscore "Main task score"
label var stop "Stop"
label var compensation "Request compensation"
label var wage_info "Transparency"
label var female "Female"
label var screeningscore "Screening Score"
label var risk_taker "Risk attitude"
label var pass "Pass"
label var transparencyXfemale "TrasparencyXWoman"

*****************************************************************************
*****************************************************************************
********************************************************************Table 1*************************************************************************
asdoc tabulate clerk group, row chi save(Table1.doc)
********************************************************************Table 2**************************************************************************
asdoc tabulate low_wage group if clerk==1, row chi save(Table2.doc)
********************************************************************Table 5**************************************************************************
bys wage_info: asdoc tabstat female, stat(N mean sd min max ) title(gender) replace save(Table5.doc)
bys wage_info: asdoc tabstat age, stat(N mean sd min max ) title(age)  save(Table5.doc)
bys wage_info: asdoc tabstat edu1-edu3, stat(N mean sd min max ) title(education)  save(Table5.doc)
bys wage_info: asdoc tabstat screeningscore, stat(N mean sd min max ) title(screeningscore)  save(Table5.doc)
bys wage_info: asdoc tabstat risk_taker, stat(N mean sd min max ) title(risk attitude) save(Table5.doc)
bys wage_info: asdoc tab country_num,   title(country) save(Table5.doc)
********************************************************************Page 11******************************************************************************
ttest taskscore if clerk, by (gender) 
bys wage_info:ttest taskscore if clerk, by (gender) 
ttest taskscore if clerk==0, by (gender) 
bys wage_info:ttest taskscore if clerk==0, by (gender) 
*******************************************************************footnote 13****************************************************************************
bys pass clerk: su taskscore
*********************************************************************Table 6*****************************************************************************

asdoc reg taskscore wage_info  female  screeningscore age risk_taker i.education i.country_num  number_female if clerk  , nested vce(hc3)  replace ///
keep(wage_info     female  screeningscore  risk_taker number_female ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(Table6.doc)


asdoc logit stop wage_info  female   screeningscore age risk_taker i.education i.country_num number_female if pass & clerk, nested vce(robust)  ///
keep(wage_info     female  screeningscore   risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(Table6.doc)

asdoc logit compensation wage_info  female  screeningscore age risk_taker number_female i.education i.country_num if clerk   , nested vce(robust)  ///
keep(  wage_info    female  screeningscore   risk_taker number_female ) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(Table6.doc)


asdoc reg taskscore wage_info  female transparencyXfemale screeningscore age risk_taker i.education i.country_num  number_female if clerk , nested vce(hc3)  ///
keep(wage_info     female transparencyXfemale screeningscore  risk_taker number_female ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(Table6.doc)


asdoc logit stop wage_info  female transparencyXfemale  screeningscore age risk_taker i.education i.country_num number_female if pass & clerk, nested vce(robust)  ///
keep(wage_info     female transparencyXfemale screeningscore   risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(Table6.doc)


asdoc logit compensation wage_info  female transparencyXfemale screeningscore age risk_taker number_female i.education i.country_num if clerk , nested vce(robust)  ///
keep(  wage_info    female transparencyXfemale screeningscore   risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(Table6.doc)
******************************************************page 13 prob of stopping under wage transparency*********************************************
logit stop i.wage_info  female   screeningscore age risk_taker i.education i.country_num number_female if pass & clerk,  vce(robust)  
margins i.wage_info, atmeans
******************************************************page 14 unjustified requests*************************************************************************
bys merit_compensation: prtest compensation, by(female)
****************************************************************************Table 7***********************************************************************
asdoc reg taskscore  female  sameXtransparency belowXtransparency  aboveXtransparency screeningscore age risk_taker i.education i.country_num number_female  if clerk , replace nested vce(hc3)  ///
keep( aboveXtransparency sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task score) save(Table7.doc)


 asdoc logit stop sameXtransparency belowXtransparency aboveXtransparency female  screeningscore age risk_taker i.education i.country_num number_female   if clerk & pass,  nested vce(robust)  ///
keep( aboveXtransparency sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop) save(Table7.doc)

 asdoc logit compensation sameXtransparency belowXtransparency aboveXtransparency female screeningscore age risk_taker i.education i.country_num number_female  if clerk ,  nested vce(robust)  ///
keep(aboveXtransparency sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Compensation) save(Table7.doc)

***************************************************************************page 15-16*********************************************************************
su taskscore if clerk & below_average & wage_info==1
su taskscore if clerk  & wage_info==0
*132.7-128=4.7
*4.7/132.7=3.5%
logit stop sameXtransparency i.belowXtransparency aboveXtransparency female  screeningscore age risk_taker i.education i.country_num number_female   if clerk & pass,   vce(robust) 
margins i.belowXtransparency, atmeans
logit compensation sameXtransparency i.belowXtransparency aboveXtransparency female screeningscore age risk_taker i.education i.country_num number_female  if clerk ,  vce(robust) 
margins i.belowXtransparency, atmeans
logit compensation sameXtransparency belowXtransparency i.aboveXtransparency female screeningscore age risk_taker i.education i.country_num number_female  if clerk ,  vce(robust) 
margins i.aboveXtransparency, atmeans
logit compensation i.sameXtransparency belowXtransparency aboveXtransparency female screeningscore age risk_taker i.education i.country_num number_female  if clerk ,  vce(robust) 
margins i.sameXtransparency, atmeans
prtest merit_compensation if compensation & pass & female, by(wage_info)
prtest merit_compensation if compensation & pass & female==0, by(wage_info)
*************************************************************Table 8 *****************************************************************************
asdoc reg taskscore female bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker i.education i.country_num number_female if clerk ,  replace nested vce(hc3)  ///
keep( female bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(task score)  save(Table8.doc)


asdoc logit stop female  bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency  aboveXtransparency screeningscore age  risk_taker i.education i.country_num number_female if clerk & pass , nested vce(robust)  ///
keep(female bothXtransparency oppositeXtransparency    samegenXtransparency sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(stop)  save(Table8.doc)


asdoc logit compensation female  bothXtransparency  oppositeXtransparency    samegenXtransparency sameXtransparency  aboveXtransparency screeningscore age risk_taker number_female i.education i.country_num if clerk,  nested vce(robust)  ///
keep( female bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(Table8.doc)

***********************************************************************page 17************************************************************************* 

su taskscore if clerk & samegenXtransparency & wage_info==1
su taskscore if clerk  & wage_info==0
*8/132.7=6%
logit stop female  i.bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency  aboveXtransparency screeningscore emplye_yearborn risk_taker i.education i.country_num number_female if clerk & pass , vce(robust)
margins i.bothXtransparency , atmean

logit compensation female  i.bothXtransparency  oppositeXtransparency    i.samegenXtransparency sameXtransparency  aboveXtransparency screeningscore emplye_yearborn risk_taker number_female i.education i.country_num if clerk,  vce(robust)
margins i.bothXtransparency , atmean
margins i.samegenXtransparency, atmeans
 
 
 
