cd "..\DATA"
use "employee_full_final", clear
cd "..\Tables"
*We established that we would not accept the responses of subjects who were too fast (timing below the 25% percentile – approximately 22 minutes) or too slow (timing above the 95% percentile – approximately 70 minutes) in completing the experiment.


gen emplye_min_dur=emplye_durationinseconds/60

su emplye_min_dur , det

drop if emplye_min_dur<21.76 

drop if  emplye_min_dur>69.93 


*We also excluded subjects who failed both attention checks, namely incorrectly stating their wage with an error of at least 5 tokens and misreporting their role (clerk or manager).


gen wrong_wage=(abs(emplye_guess_your_wage-emplye_wage)>2) 
gen wrong_wage2=(abs(emplye_guess_your_wage-emplye_wage)>5) 
replace wrong_wage2=0 if emplye_position=="Manager"


gen todrop3=(wrong_wage2==1 & emplye_misunderstood_position==1 )


drop if todrop3==1



************************************************************
************************************************************
*Renaming and creating variables
rename emplye_country country
encode country, gen (country_num)
encode emplye_maintaskresult, gen(pass)
rename pass passold
gen pass=passold-1
rename emplye_gender gender
ta gender, gen(female)
rename female1 female
rename emplye_treatment treatment
gen taskscore=emplye_maintaskscoreclerk
replace taskscore=emplye_maintaskscoremanager if emplye_maintaskscoreclerk==.
gen clerk=(emplye_maintaskscoreclerk!=.)
rename emplye_group group
gen manager=(clerk==0)
gen low_wage=(emplye_wage==150)
gen education=emplye_education
replace education=3 if education<=2
replace education=4 if education==5
replace education=education-2
replace education=3 if education==4
*In this paper we decided to merge the two treatments (T1 and T2) since they both introduced transparency in the experimental environment, and report results accordingly
gen wage_info=(treatment>0)
rename emplye_screeningtaskscore_2 screeningscore
rename  emplye_risk_taker  risk_taker
ta education, gen (edu)
gen age=2020-emplye_yearborn
gen number_female=emplye_number_female_manager+emplye_number_female_clerk
gen timer_clerk_min=substr(emplye_customtimer_mtc, 1,2)
gen timer_clerk_sec=substr(emplye_customtimer_mtc, 4,2)
destring timer_clerk_min timer_clerk_sec, replace
replace timer_clerk_min=timer_clerk_min*60
gen timer_clerk=timer_clerk_min+timer_clerk_sec
gen timer_manager_min=substr(emplye_customtimer_mtm, 1,2)
gen timer_manager_sec=substr(emplye_customtimer_mtm, 4,2)
destring timer_manager_min timer_manager_sec, replace
replace timer_manager_min=timer_manager_min*60
gen timer_manager=timer_manager_min+timer_manager_sec
gen stop=(taskscore==120 & timer_clerk!=0)
gen manager_stop=(taskscore==170  & timer_manager!=0)
replace stop =manager_stop if clerk==0
rename emplye_requestcompensation compensation 
gen transparencyXfemale=wage_info*female
gen merit_compensation=(low_wage==1 & group=="A" & emplye_average_wage_clerk!=150)
replace merit_compensation=1 if low_wage==1 & group=="B" & (emplye_mb_clerk_225==1|emplye_fb_clerk_225==1)
gen below_average_both=(emplye_wage<emplye_average_wage_male_clerk & emplye_wage<emplye_average_wage_female_clerk)
gen below_average_same=((emplye_wage<emplye_average_wage_male_clerk) & female==0 & (emplye_wage>=emplye_average_wage_female_clerk))
replace below_average_same=1 if (emplye_wage<emplye_average_wage_female_clerk) & female==1 & (emplye_wage>=emplye_average_wage_male_clerk)
gen below_average_opposite=((emplye_wage>=emplye_average_wage_male_clerk) & female==0 & (emplye_wage<emplye_average_wage_female_clerk))
replace below_average_opposite=1 if (emplye_wage>=emplye_average_wage_female_clerk) & female==1 & (emplye_wage<emplye_average_wage_male_clerk)
gen oppositeXtransparency=below_average_opposite*wage_info
gen samegenXtransparency=below_average_same*wage_info
gen bothXtransparency=below_average_both*wage_info
gen same_average=(emplye_average_wage_clerk==150)
gen below_average=(emplye_average_wage_clerk!=150 & low_wage==1)
gen above_average=(emplye_average_wage_clerk!=150 & low_wage==0)
gen aboveXtransparency=above_average*wage_info
gen belowXtransparency=below_average*wage_info
gen sameXtransparency=same_average*wage_info
ta treatment, gen (T)
rename T1 T0
rename T2 T1
rename T3 T2
gen T1Xfemale=T1*female
gen T2Xfemale=T2*female
gen aboveXT1=above_average*T1
gen belowXT1=below_average*T1
gen sameXT1=same_average*T1
gen aboveXT2=above_average*T2
gen belowXT2=below_average*T2
gen sameXT2=same_average*T2
gen samegenXT2 =below_average_same*T2 
gen oppositeXT2 =below_average_opposite*T2 
gen bothXT2 =below_average_both*T2 
gen samegenXT1 =below_average_same*T1 
gen oppositeXT1 =below_average_opposite*T1 
gen bothXT1 =below_average_both*T1 
gen gap=((emplye_average_wage_male_clerk-emplye_average_wage_female_clerk)!=0)
gen gapw=((emplye_average_wage_male_clerk-emplye_average_wage_female_clerk)>0)
gen gapm=((emplye_average_wage_male_clerk-emplye_average_wage_female_clerk)<0)
gen unexplained_gg_f=(female==1 & low_wage==1 & group=="A" & emplye_average_wage_male_clerk!=150)
replace unexplained_gg_f=1 if low_wage==1 & group=="B" & (emplye_mb_clerk_225==1) & female==1
gen unexplained_gg_m=(female==0 & low_wage==1 & group=="A" & emplye_average_wage_female_clerk!=150)
replace unexplained_gg_m=1 if low_wage==1 & group=="B" & (emplye_fb_clerk_225==1) & female==0
gen unexplained_gg= (unexplained_gg_f|unexplained_gg_m)

xtile screen = screeningscore, nq(30)


label var taskscore "Main task score"
label var stop "Stop"
label var compensation "Request compensation"
label var wage_info "Transparency"
label var female "Female"
label var screeningscore "Screening Score"
label var risk_taker "Risk attitude"
label var pass "Pass"
label var transparencyXfemale "TrasparencyXWoman"

*****************************************************************************
*****************************************************************************
****************************************************************************Tables A1-A4*******************************************************************
*Table A1
bys wage_info: asdoc tabulate clerk group, row chi replace save(A1.doc)
*Table A2
bys female: asdoc tabulate clerk group, row chi replace save(A2.doc)
*Table A3
bys wage_info: asdoc tabulate low_wage group if clerk==1, row chi replace save(A3.doc)
*Table A4
bys gender:asdoc tabulate low_wage group if clerk==1, row chi replace save(A4.doc)
*Table A5
asdoc tab emplye_sector, replace save(A5.doc)
*Table A6
asdoc tabstat stop if clerk & pass & wage_info==0, by(gender) statistics(mean) title(secrecy) replace save(A6.doc)
asdoc tabstat stop if clerk & pass & wage_info==1, by(gender) statistics(mean) title(transparency)  save(A6.doc)
asdoc tabstat compensation if clerk  & wage_info==0, by(gender) statistics(mean) title(secrecy)  save(A6.doc)
asdoc tabstat compensation if clerk  & wage_info==1, by(gender) statistics(mean) title(transparency)  save(A6.doc))
asdoc tabstat taskscore  if clerk & wage_info==0, by(gender)  statistics (mean)  title(secrecy) save(A6.doc)
asdoc tabstat taskscore  if clerk & wage_info==1, by(gender)  statistics (mean) title (transparency) save(A6.doc)
************************************************************Country Tables B1-B9***************************************************************************
********************************************************************Germany********************************************************************************
preserve 
keep if country_num==1
*Table B1
asdoc reg taskscore wage_info  female  screeningscore emplye_yearborn risk_taker i.education i.country_num  number_female if clerk  , nested vce(hc3)  replace ///
keep(wage_info     female  screeningscore  risk_taker number_female ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(TableB1.doc)
asdoc logit stop wage_info  female   screeningscore emplye_yearborn risk_taker i.education i.country_num number_female if pass & clerk, nested vce(robust)  ///
keep(wage_info     female  screeningscore   risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(TableB1.doc)
asdoc logit compensation wage_info  female  screeningscore emplye_yearborn risk_taker number_female i.education i.country_num if clerk   , nested vce(robust)  ///
keep(  wage_info    female  screeningscore   risk_taker number_female ) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableB1.doc)


asdoc reg taskscore wage_info  female transparencyXfemale screeningscore emplye_yearborn risk_taker i.education i.country_num  number_female if clerk , nested vce(hc3)  ///
keep(wage_info     female transparencyXfemale screeningscore  risk_taker number_female ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(TableB1.doc)


asdoc logit stop wage_info  female transparencyXfemale  screeningscore emplye_yearborn risk_taker i.education i.country_num number_female if pass & clerk, nested vce(robust)  ///
keep(wage_info     female transparencyXfemale screeningscore   risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(TableB1.doc)


asdoc logit compensation wage_info  female transparencyXfemale screeningscore emplye_yearborn risk_taker number_female i.education i.country_num if clerk , nested vce(robust)  ///
keep(  wage_info    female transparencyXfemale screeningscore   risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableB1.doc)

*Table B4
asdoc reg taskscore  female  sameXtransparency belowXtransparency  aboveXtransparency screeningscore emplye_yearborn risk_taker i.education i.country_num number_female  if clerk , replace nested vce(hc3)  ///
keep( aboveXtransparency sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task score) save(TableB4.doc)


 asdoc logit stop sameXtransparency belowXtransparency aboveXtransparency female  screeningscore emplye_yearborn risk_taker i.education i.country_num number_female   if clerk & pass,  nested vce(robust)  ///
keep( aboveXtransparency sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop) save(TableB4.doc)

 asdoc logit compensation sameXtransparency belowXtransparency aboveXtransparency female screeningscore emplye_yearborn risk_taker i.education i.country_num number_female  if clerk ,  nested vce(robust)  ///
keep(aboveXtransparency sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Compensation) save(TableB4.doc)
*Table B7
asdoc reg taskscore female bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker i.education i.country_num number_female if clerk ,  replace nested vce(robust)  ///
keep( female bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(task score)  save(TableB7.doc)


asdoc logit stop female  bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency  aboveXtransparency screeningscore age risk_taker i.education i.country_num number_female if clerk & pass , nested vce(robust)  ///
keep(female bothXtransparency oppositeXtransparency    samegenXtransparency sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(stop)  save(TableB7.doc)


asdoc logit compensation female  bothXtransparency  oppositeXtransparency    samegenXtransparency sameXtransparency  aboveXtransparency screeningscore age risk_taker number_female i.education i.country_num if clerk,  nested vce(robust)  ///
keep( female bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableB7.doc)
restore
**************************************************************************Poland***************************************************************************
preserve 
keep if country_num==2
*Table B2
asdoc reg taskscore wage_info  female  screeningscore age risk_taker i.education i.country_num  number_female if clerk  , nested vce(hc3)  replace ///
keep(wage_info     female  screeningscore  risk_taker number_female ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(TableB2.doc)


asdoc logit stop wage_info  female   screeningscore age risk_taker i.education i.country_num number_female if pass & clerk, nested vce(robust)  ///
keep(wage_info     female  screeningscore   risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(TableB2.doc)

asdoc logit compensation wage_info  female  screeningscore age risk_taker number_female i.education i.country_num if clerk   , nested vce(robust)  ///
keep(  wage_info    female  screeningscore   risk_taker number_female ) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableB2.doc)


asdoc reg taskscore wage_info  female transparencyXfemale screeningscore age risk_taker i.education i.country_num  number_female if clerk , nested vce(hc3)  ///
keep(wage_info     female transparencyXfemale screeningscore  risk_taker number_female ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(TableB2.doc)


asdoc logit stop wage_info  female transparencyXfemale  screeningscore age risk_taker i.education i.country_num number_female if pass & clerk, nested vce(robust)  ///
keep(wage_info     female transparencyXfemale screeningscore   risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(TableB2.doc)


asdoc logit compensation wage_info  female transparencyXfemale screeningscore age risk_taker number_female i.education i.country_num if clerk , nested vce(robust)  ///
keep(  wage_info    female transparencyXfemale screeningscore   risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableB2.doc)
*Table B5
asdoc reg taskscore  female  sameXtransparency belowXtransparency  aboveXtransparency screeningscore age risk_taker i.education i.country_num number_female  if clerk , replace nested vce(hc3)  ///
keep( aboveXtransparency sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task score) save(TableB5.doc)


 asdoc logit stop sameXtransparency belowXtransparency aboveXtransparency female  screeningscore age risk_taker i.education i.country_num number_female   if clerk & pass,  nested vce(robust)  ///
keep( aboveXtransparency sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop) save(TableB5.doc)

 asdoc logit compensation sameXtransparency belowXtransparency aboveXtransparency female screeningscore age risk_taker i.education i.country_num number_female  if clerk ,  nested vce(robust)  ///
keep(aboveXtransparency sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Compensation) save(TableB5.doc)

*Table B8
asdoc reg taskscore female bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker i.education i.country_num number_female if clerk ,  replace nested vce(robust)  ///
keep( female bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(task score)  save(TableB8.doc)


asdoc logit stop female  bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency  aboveXtransparency screeningscore age risk_taker i.education i.country_num number_female if clerk & pass , nested vce(robust)  ///
keep(female bothXtransparency oppositeXtransparency    samegenXtransparency sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(stop)  save(TableB8.doc)


asdoc logit compensation female  bothXtransparency  oppositeXtransparency    samegenXtransparency sameXtransparency  aboveXtransparency screeningscore age risk_taker number_female i.education i.country_num if clerk,  nested vce(robust)  ///
keep( female bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableB8.doc)

restore

*******************************************************************************Spain**********************************************************************
*Table B3
preserve 
keep if country_num==3
asdoc reg taskscore wage_info  female  screeningscore age risk_taker i.education i.country_num  number_female if clerk  , nested vce(hc3)  replace ///
keep(wage_info     female  screeningscore  risk_taker number_female ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(TableB3.doc)


asdoc logit stop wage_info  female   screeningscore age risk_taker i.education i.country_num number_female if pass & clerk, nested vce(robust)  ///
keep(wage_info     female  screeningscore   risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(TableB3.doc)

asdoc logit compensation wage_info  female  screeningscore age risk_taker number_female i.education i.country_num if clerk   , nested vce(robust)  ///
keep(  wage_info    female  screeningscore   risk_taker number_female ) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableB3.doc)


asdoc reg taskscore wage_info  female transparencyXfemale screeningscore age risk_taker i.education i.country_num  number_female if clerk , nested vce(hc3)  ///
keep(wage_info     female transparencyXfemale screeningscore  risk_taker number_female ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(TableB3.doc)


asdoc logit stop wage_info  female transparencyXfemale  screeningscore age risk_taker i.education i.country_num number_female if pass & clerk, nested vce(robust)  ///
keep(wage_info     female transparencyXfemale screeningscore   risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(TableB3.doc)


asdoc logit compensation wage_info  female transparencyXfemale screeningscore age risk_taker number_female i.education i.country_num if clerk , nested vce(robust)  ///
keep(  wage_info    female transparencyXfemale screeningscore   risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableB3.doc)
*Table B6
asdoc reg taskscore  female  sameXtransparency belowXtransparency  aboveXtransparency screeningscore age risk_taker i.education i.country_num number_female  if clerk , replace nested vce(hc3)  ///
keep( aboveXtransparency sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task score) save(TableB6.doc)


 asdoc logit stop sameXtransparency belowXtransparency aboveXtransparency female  screeningscore age risk_taker i.education i.country_num number_female   if clerk & pass,  nested vce(robust)  ///
keep( aboveXtransparency sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop) save(TableB6.doc)

 asdoc logit compensation sameXtransparency belowXtransparency aboveXtransparency female screeningscore age risk_taker i.education i.country_num number_female  if clerk ,  nested vce(robust)  ///
keep(aboveXtransparency sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Compensation) save(TableB6.doc)

*Table B9
asdoc reg taskscore female bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker i.education i.country_num number_female if clerk ,  replace nested vce(robust)  ///
keep( female bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(task score)  save(TableB9.doc)


asdoc logit stop female  bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency  aboveXtransparency screeningscore age risk_taker i.education i.country_num number_female if clerk & pass , nested vce(robust)  ///
keep(female bothXtransparency oppositeXtransparency    samegenXtransparency sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(stop)  save(TableB9.doc)


asdoc logit compensation female  bothXtransparency  oppositeXtransparency    samegenXtransparency sameXtransparency  aboveXtransparency screeningscore age risk_taker number_female i.education i.country_num if clerk,  nested vce(robust)  ///
keep( female bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableB9.doc)
restore

*********************************************************************Appendix C- Tables C1-C3*************************************************************
*Table C1
asdoc reg taskscore T1 T2  female  screeningscore age risk_taker i.education i.country_num  number_female if clerk  , nested vce(hc3)  replace ///
keep(T1 T2     female  screeningscore  risk_taker number_female ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(TableC1.doc)


asdoc logit stop T1 T2  female   screeningscore age risk_taker i.education i.country_num number_female if pass & clerk, nested vce(robust)  ///
keep(T1 T2     female  screeningscore   risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(TableC1.doc)

asdoc logit compensation T1 T2  female  screeningscore age risk_taker number_female i.education i.country_num if clerk   , nested vce(robust)  ///
keep(  T1 T2    female  screeningscore   risk_taker number_female ) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableC1.doc)


asdoc reg taskscore T1 T2  female T1Xfemale T2Xfemale screeningscore age risk_taker i.education i.country_num  number_female if clerk , nested vce(hc3)  ///
keep(T1 T2     female T1Xfemale T2Xfemale screeningscore  risk_taker number_female ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(TableC1.doc)


asdoc logit stop T1 T2  female T1Xfemale T2Xfemale  screeningscore age risk_taker i.education i.country_num number_female if pass & clerk, nested vce(robust)  ///
keep(T1 T2     female T1Xfemale T2Xfemale screeningscore   risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(TableC1.doc)


asdoc logit compensation T1 T2  female T1Xfemale T2Xfemale screeningscore age risk_taker number_female i.education i.country_num if clerk , nested vce(robust)  ///
keep(  T1 T2    female T1Xfemale T2Xfemale screeningscore   risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableC1.doc)

*Table C2


asdoc reg taskscore  female  sameXT2 belowXT2  aboveXT2 sameXT1 belowXT1  aboveXT1 screeningscore age risk_taker i.education i.country_num number_female  if clerk , replace nested vce(hc3)  ///
keep( aboveXT2 sameXT2 belowXT2  aboveXT1 sameXT1 belowXT1   female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task score) save(TableC2.doc)


 asdoc logit stop sameXT2 belowXT2  aboveXT2 sameXT1 belowXT1  aboveXT1 female  screeningscore age risk_taker i.education i.country_num number_female   if clerk & pass,  nested vce(robust)  ///
keep( aboveXT2 sameXT2 belowXT2  aboveXT1 sameXT1 belowXT1    female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop) save(TableC2.doc)

 asdoc logit compensation sameXT2 belowXT2  aboveXT2 sameXT1 belowXT1  aboveXT1 female screeningscore age risk_taker i.education i.country_num number_female  if clerk ,  nested vce(robust)  ///
keep(aboveXT2 sameXT2 belowXT2  aboveXT1 sameXT1 belowXT1    female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Compensation) save(TableC2.doc)
*Table C3


asdoc reg taskscore female bothXT1   oppositeXT1   samegenXT1  sameXT1 aboveXT1 bothXT2   oppositeXT2   samegenXT2  sameXT2 aboveXT2 screeningscore age risk_taker i.education i.country_num number_female if clerk ,  replace nested vce(hc3)  ///
keep(female  bothXT1   oppositeXT1   samegenXT1  sameXT1 aboveXT1 bothXT2   oppositeXT2   samegenXT2  sameXT2 aboveXT2 screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(task score)  save(TableC3.doc)


asdoc logit stop female  bothXT1   oppositeXT1   samegenXT1  sameXT1 aboveXT1 bothXT2   oppositeXT2   samegenXT2  sameXT2 aboveXT2 screeningscore age risk_taker i.education i.country_num number_female if clerk & pass , nested vce(robust)  ///
keep(female bothXT1   oppositeXT1   samegenXT1  sameXT1 aboveXT1 bothXT2   oppositeXT2   samegenXT2  sameXT2 aboveXT2 screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(stop)  save(TableC3.doc)


asdoc logit compensation female  bothXT1   oppositeXT1   samegenXT1  sameXT1 aboveXT1 bothXT2   oppositeXT2   samegenXT2  sameXT2 aboveXT2 screeningscore age risk_taker number_female i.education i.country_num if clerk,  nested vce(robust)  ///
keep( female bothXT1   oppositeXT1   samegenXT1  sameXT1 aboveXT1 bothXT2   oppositeXT2   samegenXT2  sameXT2 aboveXT2 screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableC3.doc)

**************************************************************Appendix D - Table D1-D4*********************************************************************

asdoc logit pass wage_info  female manager screeningscore age risk_taker number_female i.education i.country_num  , replace nested vce(robust)  ///
keep(  wage_info    female manager  screeningscore   risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(pass Request)  save(TableD1.doc)
asdoc logit pass wage_info  female  screeningscore age risk_taker number_female i.education i.country_num if clerk   , replace nested vce(robust)  ///
keep(  wage_info    female  screeningscore   risk_taker number_female ) label add(Country dummies, Yes, Age and Education ,Yes) cnames(pass Request)  save(TableD2.doc)
asdoc logit pass wage_info  female transparencyXfemale screeningscore age risk_taker number_female i.education i.country_num if clerk , nested vce(robust)  ///
keep(  wage_info    female transparencyXfemale screeningscore   risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableD2.doc)

asdoc logit pass sameXtransparency belowXtransparency aboveXtransparency female screeningscore age risk_taker i.education i.country_num number_female  if clerk , replace nested vce(robust)  ///
keep(aboveXtransparency sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Compensation) save(TableD3.doc)

asdoc logit pass female  bothXtransparency  oppositeXtransparency    samegenXtransparency sameXtransparency  aboveXtransparency screeningscore age  risk_taker number_female i.education i.country_num if clerk, replace nested vce(robust)  ///
keep( female bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableD4.doc)
**************************************************************Appendix E - Table E1***********************************************************************
preserve
keep if clerk==0
asdoc reg taskscore wage_info  female  screeningscore age risk_taker i.education i.country_num  emplye_number_female_manager , nested vce(hc3)  replace ///
keep(wage_info     female  screeningscore  risk_taker emplye_number_female_manager ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(tableE.doc)
asdoc logit stop wage_info  female   screeningscore age risk_taker i.education i.country_num emplye_number_female_manager if pass , nested vce(robust)  ///
keep(wage_info     female  screeningscore   risk_taker emplye_number_female_manager) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(tableE.doc)
asdoc reg taskscore wage_info  female transparencyXfemale screeningscore age risk_taker i.education i.country_num  emplye_number_female_manager , nested vce(hc3)  ///
keep(wage_info     female transparencyXfemale screeningscore  risk_taker emplye_number_female_manager ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(tableE.doc)
asdoc logit stop wage_info  female transparencyXfemale  screeningscore age risk_taker i.education i.country_num emplye_number_female_manager if pass , nested vce(robust)  ///
keep(wage_info     female transparencyXfemale screeningscore   risk_taker emplye_number_female_manager) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(tableE.doc)
restore
****************************************************************Appendix F - Table F1-F4******************************************************************
*Table F1
preserve
keep if female==1
asdoc reg taskscore    sameXtransparency belowXtransparency  aboveXtransparency screeningscore emplye_yearborn risk_taker i.education i.country_num number_female  if clerk , replace nested vce(hc3)  ///
keep( aboveXtransparency sameXtransparency belowXtransparency  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task score) save(TableF1.doc)

 asdoc logit stop sameXtransparency belowXtransparency aboveXtransparency   screeningscore emplye_yearborn risk_taker i.education i.country_num number_female   if clerk & pass,  nested vce(robust)  ///
keep( aboveXtransparency sameXtransparency belowXtransparency  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop) save(TableF1.doc)

 asdoc logit compensation sameXtransparency belowXtransparency aboveXtransparency  screeningscore emplye_yearborn risk_taker i.education i.country_num number_female  if clerk ,  nested vce(robust)  ///
keep(aboveXtransparency sameXtransparency belowXtransparency   screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Compensation) save(TableF1.doc)
restore
*Table F2
preserve
keep if female==0
asdoc reg taskscore    sameXtransparency belowXtransparency  aboveXtransparency screeningscore emplye_yearborn risk_taker i.education i.country_num number_female  if clerk , replace nested vce(hc3)  ///
keep( aboveXtransparency sameXtransparency belowXtransparency  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task score) save(TableF2.doc)


 asdoc logit stop sameXtransparency belowXtransparency aboveXtransparency   screeningscore emplye_yearborn risk_taker i.education i.country_num number_female   if clerk & pass,  nested vce(robust)  ///
keep( aboveXtransparency sameXtransparency belowXtransparency   screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop) save(TableF2.doc)

 asdoc logit compensation sameXtransparency belowXtransparency aboveXtransparency  screeningscore emplye_yearborn risk_taker i.education i.country_num number_female  if clerk ,  nested vce(robust)  ///
keep(aboveXtransparency sameXtransparency belowXtransparency   screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Compensation) save(TableF2.doc)
restore
*Table F3
preserve
keep if female==1
asdoc reg taskscore  bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore emplye_yearborn risk_taker i.education i.country_num number_female if clerk ,  replace nested vce(robust)  ///
keep(  bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore emplye_yearborn risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(task score)  save(TableF3.doc)


asdoc logit stop   bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency  aboveXtransparency screeningscore emplye_yearborn risk_taker i.education i.country_num number_female if clerk & pass , nested vce(robust)  ///
keep( bothXtransparency oppositeXtransparency    samegenXtransparency sameXtransparency aboveXtransparency screeningscore emplye_yearborn risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(stop)  save(TableF3.doc)


asdoc logit compensation   bothXtransparency  oppositeXtransparency    samegenXtransparency sameXtransparency  aboveXtransparency screeningscore emplye_yearborn risk_taker number_female i.education i.country_num if clerk,  nested vce(robust)  ///
keep(  bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore emplye_yearborn risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableF3.doc)
restore
*Table F4
preserve
keep if female==0
asdoc reg taskscore  bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore emplye_yearborn risk_taker i.education i.country_num number_female if clerk ,  replace nested vce(robust)  ///
keep(  bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore emplye_yearborn risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(task score)  save(TableF4.doc)


asdoc logit stop   bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency  aboveXtransparency screeningscore emplye_yearborn risk_taker i.education i.country_num number_female if clerk & pass , nested vce(robust)  ///
keep(bothXtransparency oppositeXtransparency    samegenXtransparency sameXtransparency aboveXtransparency screeningscore emplye_yearborn risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(stop)  save(TableF4.doc)


asdoc logit compensation   bothXtransparency  oppositeXtransparency    samegenXtransparency sameXtransparency  aboveXtransparency screeningscore emplye_yearborn risk_taker number_female i.education i.country_num if clerk,  nested vce(robust)  ///
keep(  bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore emplye_yearborn risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableF4.doc)
restore
*Table F5
preserve
keep if wage_info==1
asdoc reg taskscore  female   belowXtransparency  aboveXtransparency screeningscore emplye_yearborn risk_taker i.education i.country_num number_female  if clerk , replace nested vce(hc3)  ///
keep( aboveXtransparency  belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task score) save(TableF5.doc)


 asdoc logit stop  belowXtransparency aboveXtransparency female  screeningscore emplye_yearborn risk_taker i.education i.country_num number_female   if clerk & pass,  nested vce(robust)  ///
keep( aboveXtransparency  belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop) save(TableF5.doc)

 asdoc logit compensation  belowXtransparency aboveXtransparency female screeningscore emplye_yearborn risk_taker i.education i.country_num number_female  if clerk ,  nested vce(robust)  ///
keep(aboveXtransparency  belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Compensation) save(TableF5.doc)
restore
*table F6
preserve
keep if wage_info==1
asdoc reg taskscore female bothXtransparency   oppositeXtransparency    samegenXtransparency   aboveXtransparency screeningscore emplye_yearborn risk_taker i.education i.country_num number_female if clerk ,  replace nested vce(robust)  ///
keep( female bothXtransparency   oppositeXtransparency    samegenXtransparency   aboveXtransparency screeningscore emplye_yearborn risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(task score)  save(TableF6.doc)


asdoc logit stop female  bothXtransparency  oppositeXtransparency    samegenXtransparency    aboveXtransparency screeningscore emplye_yearborn risk_taker i.education i.country_num number_female if clerk & pass , nested vce(robust)  ///
keep(female bothXtransparency oppositeXtransparency    samegenXtransparency  aboveXtransparency screeningscore emplye_yearborn risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(stop)  save(TableF6.doc)


asdoc logit compensation female  bothXtransparency  oppositeXtransparency    samegenXtransparency   aboveXtransparency screeningscore emplye_yearborn risk_taker number_female i.education i.country_num if clerk,  nested vce(robust)  ///
keep( female bothXtransparency  oppositeXtransparency    samegenXtransparency   aboveXtransparency screeningscore emplye_yearborn risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableF6.doc)
restore
*Table F7
asdoc ta gap if clerk==1 & wage_info==1, replace save(TableF7)
asdoc ta gapw if clerk==1 & wage_info==1,  save(TableF7)
asdoc ta gapm if clerk==1 & wage_info==1,   save(TableF7)

asdoc ta unexplained_gg_f if clerk & wage_info==1, save(TableF7)
asdoc ta unexplained_gg_m if clerk & wage_info , save(TableF7)
asdoc ta unexplained_gg if clerk & wage_info , save(TableF7)

*Table F8
preserve
keep if female==0
asdoc reg taskscore wage_info gapm screeningscore age risk_taker i.education i.country_num number_female if clerk ,  replace nested vce(robust)  ///
keep(wage_info gapm age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(task score)  save(TableF8.doc)


asdoc logit stop wage_info gapm screeningscore age risk_taker i.education i.country_num number_female if clerk & pass , nested vce(robust)  ///
keep(wage_info gapm age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(stop)  save(TableF8.doc)


asdoc logit compensation wage_info screeningscore gapm age risk_taker number_female i.education i.country_num if clerk,  nested vce(robust)  ///
keep(wage_info gapm age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableF8.doc)
restore
preserve
keep if female==1
asdoc reg taskscore wage_info gapw screeningscore age risk_taker i.education i.country_num number_female if clerk ,   nested vce(robust)  ///
keep(wage_info  gapw gapm age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(task score)  save(TableF8.doc)


asdoc logit stop wage_info gapw screeningscore age risk_taker i.education i.country_num number_female if clerk & pass , nested vce(robust)  ///
keep(wage_info gapw gapm age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(stop)  save(TableF8.doc)


asdoc logit compensation wage_info gapw screeningscore age risk_taker number_female i.education i.country_num if clerk,  nested vce(robust)  ///
keep(wage_info gapw gapm age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableF8.doc)
restore

ta merit_compensation if gapw==1 & female==1 & clerk & wage_info==1
ta merit_compensation if gapw==0 & female==1 & clerk & wage_info==1
***********************************************************************Appendix G Tables G1-G3*************************************************************

*Table G1
asdoc reg taskscore wage_info  female  screeningscore emplye_yearborn risk_taker i.education i.country_num  number_female if clerk  , nested vce(cluster screen)  replace ///
keep(wage_info     female  screeningscore  risk_taker number_female ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(TableG1.doc)


asdoc logit stop wage_info  female   screeningscore emplye_yearborn risk_taker i.education i.country_num number_female if pass & clerk, nested vce(cluster screen)  ///
keep(wage_info     female  screeningscore   risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(TableG1.doc)

asdoc logit compensation wage_info  female  screeningscore emplye_yearborn risk_taker number_female i.education i.country_num if clerk   , nested vce(cluster screen)  ///
keep(  wage_info    female  screeningscore   risk_taker number_female ) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableG1.doc)


asdoc reg taskscore wage_info  female transparencyXfemale screeningscore emplye_yearborn risk_taker i.education i.country_num  number_female if clerk , nested vce(cluster screen)  ///
keep(wage_info     female transparencyXfemale screeningscore  risk_taker number_female ) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task Score)  save(TableG1.doc)


asdoc logit stop wage_info  female transparencyXfemale  screeningscore emplye_yearborn risk_taker i.education i.country_num number_female if pass & clerk, nested vce(cluster screen)  ///
keep(wage_info     female transparencyXfemale screeningscore   risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop)  save(TableG1.doc)


asdoc logit compensation wage_info  female transparencyXfemale screeningscore emplye_yearborn risk_taker number_female i.education i.country_num if clerk , nested vce(cluster screen)  ///
keep(  wage_info    female transparencyXfemale screeningscore   risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableG1.doc)

*Table G2
asdoc reg taskscore  female sameXtransparency  belowXtransparency  aboveXtransparency screeningscore age risk_taker i.education i.country_num number_female  if clerk , replace nested vce(cluster screen)  ///
keep(  sameXtransparency aboveXtransparency  belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Task score) save(TableG2.doc)


 asdoc logit stop   sameXtransparency belowXtransparency aboveXtransparency female  screeningscore age risk_taker i.education i.country_num number_female   if clerk & pass,  nested vce(cluster screen)  ///
keep(  sameXtransparency aboveXtransparency  belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Stop) save(TableG2.doc)

 asdoc logit compensation   sameXtransparency belowXtransparency aboveXtransparency female screeningscore age risk_taker i.education i.country_num number_female  if clerk ,  nested vce(cluster screen)  ///
keep(aboveXtransparency  sameXtransparency belowXtransparency female  screeningscore  risk_taker number_female) label add(Country dummies, Yes , Age and Education , Yes) cnames(Compensation) save(TableG2.doc)

*Table G3
asdoc reg taskscore female bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker i.education i.country_num number_female if clerk ,  replace nested vce(cluster screen) ///
keep( female bothXtransparency   oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(task score)  save(TableG3.doc)


asdoc logit stop female  bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency  aboveXtransparency screeningscore age risk_taker i.education i.country_num number_female if clerk & pass , nested vce(cluster screen)   ///
keep(female bothXtransparency oppositeXtransparency    samegenXtransparency sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(stop)  save(TableG3.doc)


asdoc logit compensation female  bothXtransparency  oppositeXtransparency    samegenXtransparency sameXtransparency  aboveXtransparency screeningscore age risk_taker number_female i.education i.country_num if clerk,  nested vce(cluster screen)   ///
keep( female bothXtransparency  oppositeXtransparency    samegenXtransparency  sameXtransparency aboveXtransparency screeningscore age risk_taker number_female) label add(Country dummies, Yes, Age and Education ,Yes) cnames(Compensation Request)  save(TableG3.doc)
































