

******************************************************************************************************************************************************************************************************************************************************************************************************************
***Employee experiment***************************************************************************************************************************************************************************************************************************************************************************************
***Merging and cleaning******************************************************************************************************************************************************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************************************************************************************************************************************************

cd "..\DATA"
set matsize 1000

clear all
set more off
set seed 209359834
global logdate: disp %tdCCYYNNDD date("$S_DATE","DMY")

*Import & merge data******************************************************************************************************************************************************************************************************************************************************************************************************************

*Import raw German data
import excel "Germany.xlsx", firstrow

gen country = "Germany"
destring, replace
save "employee_ger_raw", replace
clear all

*Import raw Polish data
import excel "Poland.xlsx", firstrow
gen country = "Poland"
destring completed_survey, replace force
destring screen_out, replace force
destring, replace
save "employee_pl_raw", replace

clear all

*Import raw Spanish data
import excel "Spain.xlsx",   firstrow
gen country = "Spain"
destring, replace
save "employee_esp_raw", replace

*Create full dataset
append using "employee_ger_raw.dta", force
append using "employee_pl_raw.dta", force
save "employee_full_raw", replace

label data "This file contains raw data from the GER/ESP/PL employee surveys"

clear all
use "employee_full_raw"

*Clean data******************************************************************************************************************************************************************************************************************************************************************************************************************
*Note: need to merge with age and location from Respondi
clear all
import excel "2934_behave_DE_2021_01_20.xlsx", sheet("result") firstrow
save "respondi_employee_de.dta", replace
clear all
import excel "2934_behave_PL_2021_01_20.xlsx", sheet("result") firstrow
save "respondi_employee_pl.dta", replace
clear all
import excel "2934_behave_ES_2021_01_20.xlsx", sheet("result") firstrow
save "respondi_employee_es.dta", replace
append using "respondi_employee_de.dta"
append using "respondi_employee_pl.dta"
save "merged_respondi.dta", replace

clear all
use "employee_full_raw"
foreach var of varlist * {
  rename `var' `=strlower("`var'")'
}


*Drop bugged obserevations (e.g., where we got multiple people per permutation)
drop if status=="Survey Preview" 
keep if employer_responseid!="" & completed_survey==1 & screen_out!=1
duplicates drop tic, force //  potential duplicates

*We should have 3 observations per gender for each company. We are now going to randomly drop any excess observation.
gen unique_id_2= unique_id + "_" +gender
set seed 1234 
gen double shuffle = runiform()
by unique_id_2 (shuffle), sort: gen excess_obs = _n > 3 
drop if excess_obs==1 // randomly drop excess observations 
drop shuffle excess_obs unique_id_2 // drop the vairbales used to identify excess observations

*merge respondi data
merge 1:1 tic using "merged_respondi.dta"
drop if _merge==2
replace v_32 = 1987 if v_32==19871
replace v_32 = 1997 if v_32==19973
replace v_32 = 2002 if v_32>=2002
rename v_31 gender_ // 1=male / 2=female / 3=other 
rename v_32 yearborn_ //year born
rename v_33 education_ //1 = least, and 6 = most education. it's coded slightly differently for each country (see attached codebook)
rename v_34 empl_status_ // 1= full time employed / 2= part-time employed / 5= furloughed / 6 = student
rename v_35 region_es_de //missing for poland. see codebook for definitions.
rename v_041c5 region_pl //variable specific to poland. see codebook for definitions. 

*Note: need to merge with age and location from Respondi

*Drop bugged obserevations (e.g., where we got multiple people per permutation)
drop if status=="Survey Preview" 
keep if (employer_responseid!="" & completed_survey==1 & screen_out!=1 & country!="Poland") | (employer_responseid!="" & country=="Poland")
duplicates drop tic, force //  potential duplicates

*We should have 3 observations per gender for each company. We are now going to randomly drop any excess observation.
gen unique_id_2= unique_id + "_" +gender
set seed 1234 
gen double shuffle = runiform()
by unique_id_2 (shuffle), sort: gen excess_obs = _n > 3 
drop if excess_obs==1 // randomly drop excess observations 
drop shuffle excess_obs unique_id_2 // drop the vairbales used to identify excess observations

*Create employment status variable
gen employment_status = ""
replace employment_status = "Employed full time (40 or more hours per week)" if employment_q=="VollzeitbeschÃ¤ftigt (40 oder mehr Stunden pro Woche)"
replace employment_status = "Employed part time (up to 39 hours per week)" if employment_q=="TeilzeitbeschÃ¤ftigt (bis zu 39 Stunden pro Woche)"
replace employment_status = "Self-employed" if employment_q=="SelbststÃ¤ndig"
replace employment_status = "Furloughed" if employment_q=="Beurlaubt/Kurzarbeit"
replace employment_status = "Employed full time (40 or more hours per week)" if employment_q=="Empleado/a de tiempo completo (40 horas o mÃ¡s por semana)"
replace employment_status = "Employed part time (up to 39 hours per week)" if employment_q=="Empleado/a de tiempo parcial (hasta 39 horas por semana)"
replace employment_status = "Self-employed" if employment_q=="Trabajador/a por cuenta propia"
replace employment_status = "Furloughed" if employment_q=="Suspendido/a"
replace employment_status = "Employed full time (40 or more hours per week)" if employment_q=="Praca w peÅnym wymiarze godzin (40 godz. tygodniowo lub wiÄcej)"
replace employment_status = "Employed part time (up to 39 hours per week)" if employment_q=="Praca w niepeÅnym wymiarze godzin (do 39 godz. tygodniowo)"
replace employment_status = "Self-employed" if employment_q=="Osoba samozatrudniona"
replace employment_status = "Furloughed" if employment_q=="Osoba na przymusowym urlopie"

*Label CQ variables
rename cq1 pass_cq1
label variable pass_cq1 "Passed or failed CQ1 first try"
rename cq2 pass_cq2
label variable pass_cq2 "Passed or failed CQ2 first try"
rename cq3 pass_cq3
label variable pass_cq1 "Passed or failed CQ3 first try"
rename cq4 pass_cq4
label variable pass_cq2 "Passed or failed CQ4 first try"

*Likelihood of being granted compensation (missing if assigned to manager role)
gen likelihood_compensation = q193 if q193!=. //response for those who asked for compensation
replace likelihood_compensation = q262 if q262!=. //response for those who did not ask for compensation

*Create belief about group assignment variable
gen group_belief = ""
replace group_belief = "GROUP A" if q254=="GRUPA A"
replace group_belief = "GROUP A" if q254=="GRUPO A"
replace group_belief = "GROUP A" if q254=="GRUPPE A"
replace group_belief = "GROUP B" if q254=="GRUPA B"
replace group_belief = "GROUP B" if q254=="GRUPO B"
replace group_belief = "GROUP B" if q254=="GRUPPE B"

*Rename screening task belief variables 
rename q198 belief_women_screening //belief about the number of strings solved by women in the screening task 
rename q199 belief_men_screening  //belief about the number of strings solved by men in the screening task 
rename q200 emp_belief_women_screening //belief about the employer's guess about number of strings completed by women in the screening task
rename q201 emp_belief_men_screening //belief about the employer's guess about number of strings completed by men in the screening task

*Create belief position variable
gen belief_position = ""
replace belief_position = "Manager" if q255=="Kierownik"
replace belief_position = "Manager" if q255=="ManagerIn"
replace belief_position = "Manager" if q255=="Gerente"
replace belief_position = "Clerk" if q255=="Pracownik Szeregowy"
replace belief_position = "Clerk" if q255=="SachbearbeiterIn"
replace belief_position = "Clerk" if q255=="Oficinista"

*Create quality control variable
gen misunderstood_position = 0
replace misunderstood_position = 1 if belief_position!=position //equal to one if they think their position is different to their actual position

*Rename wage guess variables (missing if belief position is manager)
rename q256 guess_your_wage 
rename q257 guess_lower_wage 
rename q258 guess_upper_wage 

*Rename main task belief variables
rename q202 belief_other_main //beliefs about the number of strings solved by other participants
rename q203 belief_your_main //beliefs about the number of strings solved by the respondent
rename q204 belief_women_main //beliefs about the number of strings solved by women
rename q205 belief_men_main //beliefs about the number of strings solved by men

*Create/rename beliefs about employer
gen belief_employer_gender = ""
replace belief_employer_gender = "Male" if q206=="Masculino"
replace belief_employer_gender = "Male" if q206=="MÃ¤nnlich"
replace belief_employer_gender = "Male" if q206=="MÄÅ¼czyzna"
replace belief_employer_gender = "Female" if q206=="Femenino"
replace belief_employer_gender = "Female" if q206=="Kobieta"
replace belief_employer_gender = "Female" if q206=="Weiblich"

gen belief_employer_same_gender = 0
replace belief_employer_same_gender = 1 if belief_employer_gender==gender //=1 if they think employer is the same gender as them

rename q208 belief_employer_weight //- if place greater weight on avatars, + if they place greater weight on group allocation

*Create why compensation variable (missing if they did not ask for compensation)
gen why_compensation = ""
replace why_compensation = "Because I think I performed better than my colleagues who got higher wage" if q259=="PoniewaÅ¼ uwaÅ¼am, Å¼e mÃ³j wynik byÅ lepszy niÅ¼ moich wspÃ³ÅpracownikÃ³w, ktÃ³rzy dostali wyÅ¼sze wynagrodzenie."
replace why_compensation = "Because I played my odds to earn a bit more" if q259=="PoniewaÅ¼ zaryzykowaÅem, aby zarobiÄ trochÄ wiÄcej."
replace why_compensation = "To punish my employer who did not assign wages in a fair way" if q259=="UkaraÄ mojego pracodawcÄ, ktÃ³ry nie przydzieliÅ wynagrodzeÅ w sprawiedliwy sposÃ³b."
replace why_compensation = "I was not afraid of losing my wage, it was low anyway" if q259=="Nie baÅem siÄ utraty mojego wynagrodzenia, i tak byÅo niskie."
replace why_compensation = "Other" if q259=="Inne powody (prosimy wskazaÄ)"
replace why_compensation = "Because I think I performed better than my colleagues who got higher wage" if q259=="Weil ich eine bessere Leistung als meine KollegInnen, die einen hÃ¶heren Lohn erhielten, hatte."
replace why_compensation = "Because I played my odds to earn a bit more" if q259=="Weil ich meine Chancen spielte, um ein bisschen mehr zu verdienen."
replace why_compensation = "To punish my employer who did not assign wages in a fair way" if q259=="Meine ArbeitgeberIn, die die LÃ¶hne in einer ungerechten Weise festgelegt hat, zu bestrafen."
replace why_compensation = "I was not afraid of losing my wage, it was low anyway" if q259=="Ich hatte keine Angst, vor meinem Lohn zu verlieren, da er sowieso niedrig war."
replace why_compensation = "Other" if q259=="Andere GrÃ¼nde (bitte angeben)."
replace why_compensation = "Because I think I performed better than my colleagues who got higher wage" if q259=="Porque creo que tuve un mejor desempeÃ±o que mis compaÃ±eros/as que recibieron un salario mayor."
replace why_compensation = "Because I played my odds to earn a bit more" if q259=="Porque juguÃ© con probabilidades para ganar un poco mÃ¡s."
replace why_compensation = "To punish my employer who did not assign wages in a fair way" if q259=="Para castigar a mi empleador/a, quien no asignÃ³ los salarios justamente."
replace why_compensation = "I was not afraid of losing my wage, it was low anyway" if q259=="No tuve miedo de perder mi salario, de todos modos era bajo."
replace why_compensation = "Other" if q259=="Otra (por favor especifique)"

*Create variables about why they did/did not continue working after the warning was shown 
gen stopped_working = ""
replace stopped_working = "Yes" if q209=="Ja"
replace stopped_working = "Yes" if q209=="Si"
replace stopped_working = "Yes" if q209=="Tak"
replace stopped_working = "No, I continued working" if q209=="Nein, ich habe weiter gearbeitet"
replace stopped_working = "No, I continued working" if q209=="No, seguÃ­ trabajando"
replace stopped_working = "No, I continued working" if q209=="Nie, pracowaÅem/am dalej"
replace stopped_working = "No, I did not reach the threshold" if q209=="Nein, ich habe die Schwelle nicht erreicht"
replace stopped_working = "No, I did not reach the threshold" if q209=="No, no lleguÃ© al mÃ­nimo"
replace stopped_working = "No, I did not reach the threshold" if q209=="Nie, nie udaÅo mi siÄ osiÄgnÄÄ wymaganego progu"

gen why_stopped_working1 = strpos(q210, "zwiÄ") > 0 //responded "I did not want to increase my employer's earnings"
gen why_stopped_working2 = strpos(q210, "Verdienst") > 0 //responded "I did not want to increase my employer's earnings"
gen why_stopped_working3 = strpos(q210, "No quise aumentar las ganancias") > 0 //responded "I did not want to increase my employer's earnings"
gen no_increase_empl_earn = . //missing if they did not stop working
replace no_increase_empl_earn = 1 if why_stopped_working1==1
replace no_increase_empl_earn = 1 if why_stopped_working2==1
replace no_increase_empl_earn = 1 if why_stopped_working3==1
replace no_increase_empl_earn = 0 if stopped_working=="Yes" & no_increase_empl_earn!=1

gen why_stopped_working4 = strpos(q210, "pracowaÄ") > 0 //responded "I did not want to work more than necessary to receive my wage"
gen why_stopped_working5 = strpos(q210, "mehr als nÃ¶tig") > 0 //responded "I did not want to work more than necessary to receive my wage"
gen why_stopped_working6 = strpos(q210, "No quise trabajar") > 0 //responded "I did not want to work more than necessary to receive my wage"
gen no_work_more_nec = . //missing if they did not stop working
replace no_work_more_nec = 1 if why_stopped_working4==1
replace no_work_more_nec = 1 if why_stopped_working5==1
replace no_work_more_nec = 1 if why_stopped_working6==1
replace no_work_more_nec = 0 if stopped_working=="Yes" & no_work_more_nec!=1

gen why_stopped_working7 = strpos(q210, "zadanie") > 0 //responded "I was tireed of doing the task"
gen why_stopped_working8 = strpos(q210, "es leid war") > 0 //responded "I was tireed of doing the task"
gen why_stopped_working9 = strpos(q210, "Estaba cansado/a de realizar") > 0 //responded "I was tireed of doing the task"
gen was_tired = . //missing if they did not stop working
replace was_tired = 1 if why_stopped_working7==1
replace was_tired = 1 if why_stopped_working8==1
replace was_tired = 1 if why_stopped_working9==1
replace was_tired = 0 if stopped_working=="Yes" & was_tired!=1

gen why_stopped_working10 = strpos(q210, "Inne") > 0 //responded "Other"
gen why_stopped_working11 = strpos(q210, "Andere GrÃ¼nde") > 0 //responded "Other"
gen why_stopped_working12 = strpos(q210, "Otra razÃ³n") > 0 //responded "Other"
gen other_reason_quit = . //missing if they did not stop working
replace other_reason_quit = 1 if why_stopped_working10==1
replace other_reason_quit = 1 if why_stopped_working11==1
replace other_reason_quit = 1 if why_stopped_working12==1
replace other_reason_quit = 0 if stopped_working=="Yes" & other_reason_quit!=1

gen why_continued_working1 = strpos(q211, "Aby zwiÄkszyÄ dochody mojego") > 0 //responded "To increase my employer's earnings"
gen why_continued_working2 = strpos(q211, "Um den Verdienst meiner ArbeitgeberIn") > 0 //responded "To increase my employer's earnings"
gen why_continued_working3 = strpos(q211, "Para aumentar las ganancias de mi") > 0 //responded "To increase my employer's earnings"
gen increase_empl_earning = . //missing if they did not continue
replace increase_empl_earning = 1 if why_continued_working1==1
replace increase_empl_earning = 1 if why_continued_working2==1
replace increase_empl_earning = 1 if why_continued_working3==1
replace increase_empl_earning = 0 if stopped_working=="No, I continued working" & increase_empl_earning!=1

gen why_continued_working4 = strpos(q211, "PoniewaÅ¼ zadanie sprawiaÅ") > 0 //responded "I enjoyed the task"
gen why_continued_working5 = strpos(q211, "Weil mir die Aufgabe SpaÃ") > 0 //responded "I enjoyed the task"
gen why_continued_working6 = strpos(q211, "Porque disfrutÃ© la tarea") > 0 //responded "I enjoyed the task"
gen enjoyed_task = . //missing if they did not continue
replace enjoyed_task = 1 if why_continued_working4==1
replace enjoyed_task = 1 if why_continued_working5==1
replace enjoyed_task = 1 if why_continued_working6==1
replace enjoyed_task = 0 if stopped_working=="No, I continued working" & enjoyed_task!=1

gen why_continued_working7 = strpos(q211, "Aby siÄ sprawdziÄ") > 0 //responded "To challenge myself"
gen why_continued_working8 = strpos(q211, "Um mir selbst eine Herausforderung") > 0 //responded "To challenge myself"
gen why_continued_working9 = strpos(q211, "Para desafiarme a mÃ") > 0 //responded "To challenge myself"
gen challenge_myself = . //missing if they did not continue
replace challenge_myself = 1 if why_continued_working7==1
replace challenge_myself = 1 if why_continued_working8==1
replace challenge_myself = 1 if why_continued_working9==1
replace challenge_myself = 0 if stopped_working=="No, I continued working" & challenge_myself!=1

gen why_continued_working10 = strpos(q211, "Aby udowodniÄ") > 0 //responded "To prove a point with my employer, showing I am worth more than my wage"
gen why_continued_working11 = strpos(q211, "Um meine ArbeitgeberIn zu beweisen") > 0 //responded "To prove a point with my employer, showing I am worth more than my wage"
gen why_continued_working12 = strpos(q211, "Para probarle a mi empleador/a") > 0 //responded "To prove a point with my employer, showing I am worth more than my wage"
gen prove_point = . //missing if they did not continue
replace prove_point = 1 if why_continued_working10==1
replace prove_point = 1 if why_continued_working11==1
replace prove_point = 1 if why_continued_working12==1
replace prove_point = 0 if stopped_working=="No, I continued working" & prove_point!=1

gen why_continued_working13 = strpos(q211, "ChciaÅem/am byÄ") > 0 //responded "I wanted to be a good employee"
gen why_continued_working14 = strpos(q211, "Ich wollte eine gute MitarbeiterIn") > 0 //responded "I wanted to be a good employee"
gen why_continued_working15 = strpos(q211, "QuerÃ­a ser un/a buen/a") > 0 //responded "I wanted to be a good employee"
gen good_employee = . //missing if they did not continue
replace good_employee = 1 if why_continued_working13==1
replace good_employee = 1 if why_continued_working14==1
replace good_employee = 1 if why_continued_working15==1
replace good_employee = 0 if stopped_working=="No, I continued working" & good_employee!=1

gen why_continued_working16 = strpos(q211, "Inne") > 0 //responded "Other"
gen why_continued_working17 = strpos(q211, "Andere GrÃ¼nde") > 0 //responded "Other"
gen why_continued_working18 = strpos(q211, "Otras razones") > 0 //responded "Other"
gen other_reason_continue = . //missing if they did not continue
replace other_reason_continue = 1 if why_continued_working16==1
replace other_reason_continue = 1 if why_continued_working17==1
replace other_reason_continue = 1 if why_continued_working18==1
replace other_reason_continue = 0 if stopped_working=="No, I continued working" & other_reason_continue!=1

*Rename risk variable
rename q215 risk_taker //0-10 with 10 being very much prepared to take risk and 0 being not at all prepared to take risk

*Create variables related to male and female earnings
gen equal_earnings = ""
replace equal_earnings = "Women earn much more than men" if q216=="Kobiety majÄ duÅ¼o wyÅ¼sze zarobki niÅ¼ mÄÅ¼czyÅºni"
replace equal_earnings = "Women earn slightly more than men" if q216=="Kobiety majÄ nieco wyÅ¼sze zarobki niÅ¼ mÄÅ¼czyÅºni"
replace equal_earnings = "Women earn the same as men" if q216=="Kobiety majÄ takie same zarobki jak mÄÅ¼czyÅºni"
replace equal_earnings = "Men earn slightly more than women" if q216=="MÄÅ¼czyÅºni majÄ nieco wyÅ¼sze zarobki niÅ¼ kobiety"
replace equal_earnings = "Men earn much more than women" if q216=="MÄÅ¼czyÅºni majÄ duÅ¼o wyÅ¼sze zarobki niÅ¼ kobiety"
replace equal_earnings = "Not sure" if q216=="Nie mam pewnoÅci"

replace equal_earnings = "Women earn much more than men" if q216=="Las mujeres ganan mucho mÃ¡s que los hombres."
replace equal_earnings = "Women earn slightly more than men" if q216=="Las mujeres ganan un poco mÃ¡s que los hombres."
replace equal_earnings = "Women earn the same as men" if q216=="Las mujeres ganan lo mismo que los hombres."
replace equal_earnings = "Men earn slightly more than women" if q216=="Los hombres ganan un poco mÃ¡s que las mujeres."
replace equal_earnings = "Men earn much more than women" if q216=="Los hombres ganan mucho mÃ¡s que las mujeres."
replace equal_earnings = "Not sure" if q216=="No estoy seguro/a."

replace equal_earnings = "Women earn much more than men" if q216=="Frauen verdienen viel mehr als MÃ¤nner."
replace equal_earnings = "Women earn slightly more than men" if q216=="Frauen verdienen etwas mehr als MÃ¤nner."
replace equal_earnings = "Women earn the same as men" if q216=="Frauen verdienen das gleiche wie MÃ¤nner."
replace equal_earnings = "Men earn slightly more than women" if q216=="MÃ¤nner verdienen etwas mehr als Frauen."
replace equal_earnings = "Men earn much more than women" if q216=="MÃ¤nner verdienen viel mehr als Frauen."
replace equal_earnings = "Not sure" if q216=="Nicht sicher."
label variable equal_earnings "In your company, do you think that men and women who work full-time and who hold the same position earn as much? (Including bonuses and other incentives)"

gen why_women_earn_more1 = strpos(q217, "Lepsze umiejÄtnoÅci negocjacyjne") > 0 //responded "Better negotiation skills"
gen why_women_earn_more2 = strpos(q217, "Besseres Verhandlungsgeschick") > 0 //responded "Better negotiation skills"
gen why_women_earn_more3 = strpos(q217, "Mejores habilidades de") > 0 //responded "Better negotiation skills"
gen women_better_negotiation = . //missing if they think men earn more
replace women_better_negotiation = 1 if why_women_earn_more1==1
replace women_better_negotiation = 1 if why_women_earn_more2==1
replace women_better_negotiation = 1 if why_women_earn_more3==1
replace women_better_negotiation = 0 if women_better_negotiation!=1 & equal_earnings=="Women earn much more than men"
replace women_better_negotiation = 0 if women_better_negotiation!=1 & equal_earnings=="Women earn slightly more than men"

gen why_women_earn_more4 = strpos(q217, "WyÅ¼sza produktywnoÅ") > 0 //responded "Higher productivity"
gen why_women_earn_more5 = strpos(q217, "HÃ¶here ProduktivitÃ¤t") > 0 //responded "Higher productivity"
gen why_women_earn_more6 = strpos(q217, "Mayor productividad") > 0 //responded "Higher productivity"
gen women_better_productivity = . //missing if they think men earn more
replace women_better_productivity = 1 if why_women_earn_more4==1
replace women_better_productivity = 1 if why_women_earn_more5==1
replace women_better_productivity = 1 if why_women_earn_more6==1
replace women_better_productivity = 0 if women_better_productivity!=1 & equal_earnings=="Women earn much more than men"
replace women_better_productivity = 0 if women_better_productivity!=1 & equal_earnings=="Women earn slightly more than men"

gen why_women_earn_more7 = strpos(q217, "WiÄksza ambicja") > 0 //responded "More ambition"
gen why_women_earn_more8 = strpos(q217, " Mehr Ehrgeiz.") > 0 //responded "More ambition"
gen why_women_earn_more9 = strpos(q217, "MÃ¡s ambiciÃ³n") > 0 //responded "More ambition"
gen women_better_ambition = . //missing if they think men earn more
replace women_better_ambition = 1 if why_women_earn_more7==1
replace women_better_ambition = 1 if why_women_earn_more8==1
replace women_better_ambition = 1 if why_women_earn_more9==1
replace women_better_ambition = 0 if women_better_ambition!=1 & equal_earnings=="Women earn much more than men"
replace women_better_ambition = 0 if women_better_ambition!=1 & equal_earnings=="Women earn slightly more than men"

gen why_women_earn_more10 = strpos(q217, "WiÄksza zauwaÅ¼alnoÅ") > 0 //responded "Higher visibility"
gen why_women_earn_more11 = strpos(q217, "HÃ¶here Sichtbarkeit.") > 0 //responded "Higher visibility"
gen why_women_earn_more12 = strpos(q217, "Mayor visibilidad") > 0 //responded "Higher visibility"
gen women_better_visibility = . //missing if they think men earn more
replace women_better_visibility = 1 if why_women_earn_more10==1
replace women_better_visibility = 1 if why_women_earn_more11==1
replace women_better_visibility = 1 if why_women_earn_more12==1
replace women_better_visibility = 0 if women_better_visibility!=1 & equal_earnings=="Women earn much more than men"
replace women_better_visibility = 0 if women_better_visibility!=1 & equal_earnings=="Women earn slightly more than men"

gen why_women_earn_more13 = strpos(q217, "Mentorstwo") > 0 //responded "Mentorship"
gen why_women_earn_more14 = strpos(q217, "Mentorship.") > 0 //responded "Mentorship"
gen why_women_earn_more15 = strpos(q217, "MentorÃ­a") > 0 //responded "Mentorship"
gen women_better_mentorship = . //missing if they think men earn more
replace women_better_mentorship = 1 if why_women_earn_more13==1
replace women_better_mentorship = 1 if why_women_earn_more14==1
replace women_better_mentorship = 1 if why_women_earn_more15==1
replace women_better_mentorship = 0 if women_better_mentorship!=1 & equal_earnings=="Women earn much more than men"
replace women_better_mentorship = 0 if women_better_mentorship!=1 & equal_earnings=="Women earn slightly more than men"

gen why_women_earn_more16 = strpos(q217, "Dyskryminacja ze wzglÄ") > 0 //responded "Gender discrimination"
gen why_women_earn_more17 = strpos(q217, "Geschlechts") > 0 //responded "Gender discrimination"
gen why_women_earn_more18 = strpos(q217, "DiscriminaciÃ³n") > 0 //responded "Gender discrimination"
gen women_better_discrimination = . //missing if they think men earn more
replace women_better_discrimination = 1 if why_women_earn_more16==1
replace women_better_discrimination = 1 if why_women_earn_more17==1
replace women_better_discrimination = 1 if why_women_earn_more18==1
replace women_better_discrimination = 0 if women_better_discrimination!=1 & equal_earnings=="Women earn much more than men"
replace women_better_discrimination = 0 if women_better_discrimination!=1 & equal_earnings=="Women earn slightly more than men"

gen why_women_earn_more19 = strpos(q217, "Inne") > 0 //responded "Other"
gen why_women_earn_more20 = strpos(q217, "Sonstiges") > 0 //responded "Other"
gen why_women_earn_more21 = strpos(q217, "Otros") > 0 //responded "Other"
gen women_better_other = . //missing if they think men earn more
replace women_better_other = 1 if why_women_earn_more19==1
replace women_better_other = 1 if why_women_earn_more20==1
replace women_better_other = 1 if why_women_earn_more21==1
replace women_better_other = 0 if women_better_other!=1 & equal_earnings=="Women earn much more than men"
replace women_better_other = 0 if women_better_other!=1 & equal_earnings=="Women earn slightly more than men"

gen why_men_earn_more1 = strpos(q217, "Lepsze umiejÄtnoÅci negocjacyjne") > 0 //responded "Better negotiation skills"
gen why_men_earn_more2 = strpos(q217, "Besseres Verhandlungsgeschick") > 0 //responded "Better negotiation skills"
gen why_men_earn_more3 = strpos(q217, "Mejores habilidades de") > 0 //responded "Better negotiation skills"
gen men_better_negotiation = . //missing if they think women earn more
replace men_better_negotiation = 1 if why_men_earn_more1==1
replace men_better_negotiation = 1 if why_men_earn_more2==1
replace men_better_negotiation = 1 if why_men_earn_more3==1
replace men_better_negotiation = 0 if men_better_negotiation!=1 & equal_earnings=="Men earn much more than women"
replace men_better_negotiation = 0 if men_better_negotiation!=1 & equal_earnings=="Men earn slightly more than women"

gen why_men_earn_more4 = strpos(q217, "WyÅ¼sza produktywnoÅ") > 0 //responded "Higher productivity"
gen why_men_earn_more5 = strpos(q217, "HÃ¶here ProduktivitÃ¤t") > 0 //responded "Higher productivity"
gen why_men_earn_more6 = strpos(q217, "Mayor productividad") > 0 //responded "Higher productivity"
gen men_better_productivity = . //missing if they think men earn more
replace men_better_productivity = 1 if why_men_earn_more4==1
replace men_better_productivity = 1 if why_men_earn_more5==1
replace men_better_productivity = 1 if why_men_earn_more6==1
replace men_better_productivity = 0 if men_better_productivity!=1 & equal_earnings=="Men earn much more than women"
replace men_better_productivity = 0 if men_better_productivity!=1 & equal_earnings=="Men earn slightly more than women"

gen why_men_earn_more7 = strpos(q217, "WiÄksza ambicja") > 0 //responded "More ambition"
gen why_men_earn_more8 = strpos(q217, " Mehr Ehrgeiz.") > 0 //responded "More ambition"
gen why_men_earn_more9 = strpos(q217, "MÃ¡s ambiciÃ³n") > 0 //responded "More ambition"
gen men_better_ambition = . //missing if they think men earn more
replace men_better_ambition = 1 if why_men_earn_more7==1
replace men_better_ambition = 1 if why_men_earn_more8==1
replace men_better_ambition = 1 if why_men_earn_more9==1
replace men_better_ambition = 0 if men_better_ambition!=1 & equal_earnings=="Men earn much more than women"
replace men_better_ambition = 0 if men_better_ambition!=1 & equal_earnings=="Men earn slightly more than women"

gen why_men_earn_more10 = strpos(q217, "WiÄksza zauwaÅ¼alnoÅ") > 0 //responded "Higher visibility"
gen why_men_earn_more11 = strpos(q217, "HÃ¶here Sichtbarkeit.") > 0 //responded "Higher visibility"
gen why_men_earn_more12 = strpos(q217, "Mayor visibilidad") > 0 //responded "Higher visibility"
gen men_better_visibility = . //missing if they think men earn more
replace men_better_visibility = 1 if why_men_earn_more10==1
replace men_better_visibility = 1 if why_men_earn_more11==1
replace men_better_visibility = 1 if why_men_earn_more12==1
replace men_better_visibility = 0 if men_better_visibility!=1 & equal_earnings=="Men earn much more than women"
replace men_better_visibility = 0 if men_better_visibility!=1 & equal_earnings=="Men earn slightly more than women"

gen why_men_earn_more13 = strpos(q217, "Mentorstwo") > 0 //responded "Mentorship"
gen why_men_earn_more14 = strpos(q217, "Mentorship.") > 0 //responded "Mentorship"
gen why_men_earn_more15 = strpos(q217, "MentorÃ­a") > 0 //responded "Mentorship"
gen men_better_mentorship = . //missing if they think men earn more
replace men_better_mentorship = 1 if why_men_earn_more13==1
replace men_better_mentorship = 1 if why_men_earn_more14==1
replace men_better_mentorship = 1 if why_men_earn_more15==1
replace men_better_mentorship = 0 if men_better_mentorship!=1 & equal_earnings=="Men earn much more than women"
replace men_better_mentorship = 0 if men_better_mentorship!=1 & equal_earnings=="Men earn slightly more than women"

gen why_men_earn_more16 = strpos(q217, "Dyskryminacja ze wzglÄ") > 0 //responded "Gender discrimination"
gen why_men_earn_more17 = strpos(q217, "Geschlechts") > 0 //responded "Gender discrimination"
gen why_men_earn_more18 = strpos(q217, "DiscriminaciÃ³n") > 0 //responded "Gender discrimination"
gen men_better_discrimination = . //missing if they think men earn more
replace men_better_discrimination = 1 if why_men_earn_more16==1
replace men_better_discrimination = 1 if why_men_earn_more17==1
replace men_better_discrimination = 1 if why_men_earn_more18==1
replace men_better_discrimination = 0 if men_better_discrimination!=1 & equal_earnings=="Men earn much more than women"
replace men_better_discrimination = 0 if men_better_discrimination!=1 & equal_earnings=="Men earn slightly more than women"

gen why_men_earn_more19 = strpos(q217, "Inne") > 0 //responded "Other"
gen why_men_earn_more20 = strpos(q217, "Sonstiges") > 0 //responded "Other"
gen why_men_earn_more21 = strpos(q217, "Otros") > 0 //responded "Other"
gen men_better_other = . //missing if they think men earn more
replace men_better_other = 1 if why_men_earn_more19==1
replace men_better_other = 1 if why_men_earn_more20==1
replace men_better_other = 1 if why_men_earn_more21==1
replace men_better_other = 0 if men_better_other!=1 & equal_earnings=="Men earn much more than women"
replace men_better_other = 0 if men_better_other!=1 & equal_earnings=="Men earn slightly more than women"

*Create variables related what would happen in their company
gen what_happen_company1 = strpos(q220, "SpowodowaÅoby to wzrost wynagrodzeÅ") > 0 //responded "It would make women's wages increase"
gen what_happen_company2 = strpos(q220, "Die LÃ¶hne von Frauen wÃ¼rden steigen") > 0 //responded "It would make women's wages increase"
gen what_happen_company3 = strpos(q220, "HarÃ­a aumentar los salarios") > 0 //responded "It would make women's wages increase"
gen increase_w_wages = 0
replace increase_w_wages = 1 if what_happen_company1==1
replace increase_w_wages = 1 if what_happen_company2==1
replace increase_w_wages = 1 if what_happen_company3==1

gen what_happen_company4 = strpos(q220, "SpowodowaÅoby to spadek wynagrodzeÅ") > 0 //responded "It would make men's wages decrease"
gen what_happen_company5 = strpos(q220, "Die LÃ¶hne von MÃ¤nnern wÃ¼rden sinken") > 0 //responded "It would make men's wages decrease"
gen what_happen_company6 = strpos(q220, "HarÃ­a disminuir los salarios") > 0 //responded "It would make men's wages decrease"
gen decrease_m_wages = 0
replace decrease_m_wages = 1 if what_happen_company4==1
replace decrease_m_wages = 1 if what_happen_company5==1
replace decrease_m_wages = 1 if what_happen_company6==1

gen what_happen_company7 = strpos(q220, "Nie miaÅoby to wpÅywu, gdyÅ¼ w moje") > 0 //responded "No effect because there are no differences in pay in my company"
gen what_happen_company8 = strpos(q220, "Keine Auswirkung, weil es in meinem") > 0 //responded "No effect because there are no differences in pay in my company"
gen what_happen_company9 = strpos(q220, "Sin efecto porque no hay") > 0 //responded "No effect because there are no differences in pay in my company"
gen no_effect_wages1 = 0
replace no_effect_wages1 = 1 if what_happen_company7==1
replace no_effect_wages1 = 1 if what_happen_company8==1
replace no_effect_wages1 = 1 if what_happen_company9==1

gen what_happen_company10 = strpos(q220, "Nie miaÅoby to wpÅywu, gdyÅ¼ rÃ³Å¼n") > 0 //responded "No effect because differences in pay in my company are a well-known fact"
gen what_happen_company11 = strpos(q220, "Keine Wirkung, weil Unterschiede") > 0 //responded "No effect because differences in pay in my company are a well-known fact"
gen what_happen_company12 = strpos(q220, "Sin efecto porque las diferencias") > 0 //responded "No effect because differences in pay in my company are a well-known fact"
gen no_effect_wages2 = 0
replace no_effect_wages2 = 1 if what_happen_company10==1
replace no_effect_wages2 = 1 if what_happen_company11==1
replace no_effect_wages2 = 1 if what_happen_company12==1

gen what_happen_company13 = strpos(q220, "WywoÅaÅoby to konflikty") > 0 //responded "It would generate conflicts"
gen what_happen_company14 = strpos(q220, "Es wÃ¼rde Konflikte erzeugen") > 0 //responded "It would generate conflicts"
gen what_happen_company15 = strpos(q220, "GenerarÃ­a conflictos") > 0 //responded "It would generate conflicts"
gen generate_conflict = 0
replace generate_conflict = 1 if what_happen_company13==1
replace generate_conflict = 1 if what_happen_company14==1
replace generate_conflict = 1 if what_happen_company15==1

gen what_happen_company16 = strpos(q220, "MiaÅoby to pozytywny wpÅ") > 0 //responded "It would have positive effects on productivity"
gen what_happen_company17 = strpos(q220, "Es hÃ¤tte positive") > 0 //responded "It would have positive effects on productivity"
gen what_happen_company18 = strpos(q220, "TendrÃ­a efectos positivos") > 0 //responded "It would have positive effects on productivity"
gen positive_productivity = 0
replace positive_productivity = 1 if what_happen_company16==1
replace positive_productivity = 1 if what_happen_company17==1
replace positive_productivity = 1 if what_happen_company18==1

gen what_happen_company19 = strpos(q220, "MiaÅoby to negatywny") > 0 //responded "It would have negative effects on productivity"
gen what_happen_company20 = strpos(q220, "Es hÃ¤tte negative") > 0 //responded "It would have negative effects on productivity"
gen what_happen_company21 = strpos(q220, "TendrÃ­a efectos negativos") > 0 //responded "It would have negative effects on productivity"
gen negative_productivity = 0
replace negative_productivity = 1 if what_happen_company19==1
replace negative_productivity = 1 if what_happen_company20==1
replace negative_productivity = 1 if what_happen_company21==1

gen no_effect_productivity = 0
replace no_effect_productivity = 1 if negative_productivity==0 & positive_productivity==0

gen what_happen_company22 = strpos(q220, "Inne (prosimy") > 0 //responded "Other"
gen what_happen_company23 = strpos(q220, "Sonstiges") > 0 //responded "Other"
gen what_happen_company24 = strpos(q220, "Otro (por favor,") > 0 //responded "Other"
gen other_effect_information = 0
replace other_effect_information = 1 if what_happen_company22==1
replace other_effect_information = 1 if what_happen_company23==1
replace other_effect_information = 1 if what_happen_company24==1

*Create variables related to social acceptability of discussing wages etc.
gen socially_acceptible_wages = "Highly acceptable" if q221=="Muy aceptable"
replace socially_acceptible_wages = "Highly acceptable" if q221=="Wysoce akceptowalne"
replace socially_acceptible_wages = "Highly acceptable" if q221=="Sehr akzeptabel"
replace socially_acceptible_wages = "Somewhat acceptable" if q221=="Algo aceptable"
replace socially_acceptible_wages = "Somewhat acceptable" if q221=="Raczej akceptowalne"
replace socially_acceptible_wages = "Somewhat acceptable" if q221=="Eher akzeptabel"
replace socially_acceptible_wages = "Somewhat unacceptable" if q221=="Algo inaceptable"
replace socially_acceptible_wages = "Somewhat unacceptable" if q221=="Raczej nieakceptowalne"
replace socially_acceptible_wages = "Somewhat unacceptable" if q221=="Eher inakzeptabel"
replace socially_acceptible_wages = "Highly unacceptable" if q221=="Altamente inaceptable"
replace socially_acceptible_wages = "Highly unacceptable" if q221=="Wysoce nieakceptowalne"
replace socially_acceptible_wages = "Highly unacceptable" if q221=="Sehr inakzeptabel"

gen comfortable_wages = "Very comfortable" if q222=="Muy cÃ³modo/a."
replace comfortable_wages = "Very comfortable" if q222=="Bardzo swobodnie"
replace comfortable_wages = "Very comfortable" if q222=="Sehr wohl"
replace comfortable_wages = "Seomwhat comfortable" if q222=="Algo cÃ³modo/a."
replace comfortable_wages = "Seomwhat comfortable" if q222=="Raczej swobodnie"
replace comfortable_wages = "Seomwhat comfortable" if q222=="Eher wohl"
replace comfortable_wages = "Seomwhat uncomfortable" if q222=="Algo incÃ³modo/a."
replace comfortable_wages = "Seomwhat uncomfortable" if q222=="Raczej nieswobodnie"
replace comfortable_wages = "Seomwhat uncomfortable" if q222=="Eher unwohl"
replace comfortable_wages = "Very uncomfortable" if q222=="Muy incÃ³modo/a."
replace comfortable_wages = "Very uncomfortable" if q222=="Bardzo nieswobodnie"
replace comfortable_wages = "Very uncomfortable" if q222=="Sehr unwohl"

gen asked_information = "Yes, I think it is an employee's right to know" if q223=="Ja, ich denke, es ist das Recht eines Arbeitnehmers dies zu wissen"
replace asked_information = "Yes, I think it is an employee's right to know" if q223=="Tak, gdyÅ¼ uwaÅ¼am, Å¼e pracownik ma prawo znaÄ takie informacje" 
replace asked_information = "Yes, I think it is an employee's right to know" if q223=="SÃ­, creo que los/las empleados/as tienen derecho a saberlo"
replace asked_information = "No, I can ask my colleagues" if q223=="Nein, ich kann meine Kollegen fragen"
replace asked_information = "No, I can ask my colleagues" if q223=="Nie, mogÄ zapytaÄ swoich wspÃ³ÅpracownikÃ³w"
replace asked_information = "No, I can ask my colleagues" if q223=="No, puedo preguntar a mis compaÃ±eros/as"
replace asked_information = "No, I would be afraid of the consequences" if q223=="Nein, ich hÃ¤tte Angst vor den Konsequenzen"
replace asked_information = "No, I would be afraid of the consequences" if q223=="Nie, obawiaÅ(a)bym siÄ konsekwencji"
replace asked_information = "No, I would be afraid of the consequences" if q223=="No, tendrÃ­a miedo de las consecuencias"
replace asked_information = "No, this information is already available in my company" if q223=="Nein, diese Informationen sind in meinem Unternehmen bereits verfÃ¼gbar."
replace asked_information = "No, this information is already available in my company" if q223=="Nie, tego typu informacje sÄ juÅ¼ udostÄpniane w mojej firmie."
replace asked_information = "No, this information is already available in my company" if q223=="No, esta informaciÃ³n ya estÃ¡ disponible en mi empresa."
replace asked_information = "No, I am not interested in this information" if q223=="Nein, ich bin an diesen Informationen nicht interessiert."
replace asked_information = "No, I am not interested in this information" if q223=="Nie, nie interesujÄ mnie tego typu informacje"
replace asked_information = "No, I am not interested in this information" if q223=="No, no me interesa esta informaciÃ³n"
replace asked_information = "Other" if q223=="Sonstiges (bitte erklÃ¤ren)"
replace asked_information = "Other" if q223=="Inne (prosimy wyjaÅniÄ)"
replace asked_information = "Other" if q223=="Otro (explique)"

gen consider_asking = "Yes" if q224=="Ja"
replace consider_asking = "Yes" if q224=="SÃ­"
replace consider_asking = "Yes" if q224=="Tak"
replace consider_asking = "No" if q224=="Nein"
replace consider_asking = "No" if q224=="No"
replace consider_asking = "No" if q224=="Nie"

gen why_not_ask = "I am not interested" if q260=="Nie jestem zainteresowany/a" //missing if they answered yes to "consider_asking"
replace why_not_ask = "I am not interested" if q260=="Ich interesse mich nicht dafÃ¼r."
replace why_not_ask = "I am not interested" if q260=="No estoy interesado/a."
replace why_not_ask = "I would be afraid of the consequences" if q260=="BaÅbym/baÅabym siÄ konsekwencji"
replace why_not_ask = "I would be afraid of the consequences" if q260=="Ich wÃ¼rde Angst vor den Konsequenzen haben."
replace why_not_ask = "I would be afraid of the consequences" if q260=="TemerÃ­a de las consecuencias."
replace why_not_ask = "I am not confident enough to ask" if q260=="Nie jestem na tyle pewny/a siebie, Å¼eby zapytaÄ."
replace why_not_ask = "I am not confident enough to ask" if q260=="Ich bin nicht zuversichtlich genug zu fragen."
replace why_not_ask = "I am not confident enough to ask" if q260=="No tengo la suficiente confianza para preguntar."
replace why_not_ask = "Other" if q260=="Inne (prosimy wyjaÅniÄ)"
replace why_not_ask = "Other" if q260=="Sonstiges (bitte erklÃ¤ren)"
replace why_not_ask = "Other" if q260=="Otra (por favor especifique)"
replace why_not_ask = "Other" if q260=="-99"

*Create variables related to their occupation and sector
gen employment_role =""
replace employment_role = "Upper management" if q236=="Oberes Management."
replace employment_role = "Upper management" if q236=="Alta direcciÃ³n"
replace employment_role = "Upper management" if q236=="Kadra kierownicza wyÅ¼szego szczebla"
replace employment_role = "Middle management" if q236=="Mittleres Management."
replace employment_role = "Middle management" if q236=="Gerencia intermedia"
replace employment_role = "Middle management" if q236=="Kadra kierownicza Åredniego szczebla"
replace employment_role = "Junior management" if q236=="NachwuchsfÃ¼hrungskraft."
replace employment_role = "Junior management" if q236=="Gerencia junior"
replace employment_role = "Junior management" if q236=="Kadra kierownicza niÅ¼szego szczebla"
replace employment_role = "Administrative staff" if q236=="Verwaltungspersonal."
replace employment_role = "Administrative staff" if q236=="Personal administrativo"
replace employment_role = "Administrative staff" if q236=="Kadra administracyjna"
replace employment_role = "Support staff" if q236=="Support Personal."
replace employment_role = "Support staff" if q236=="Personal de apoyo"
replace employment_role = "Support staff" if q236=="Kadra pomocnicza"
replace employment_role = "Trained professional" if q236=="Trained professional."
replace employment_role = "Trained professional" if q236=="Profesional capacitado/a"
replace employment_role = "Trained professional" if q236=="Wykwalifikowany specjalista"
replace employment_role = "Researcher" if q236=="Forscher."
replace employment_role = "Researcher" if q236=="Investigador/a"
replace employment_role = "Researcher" if q236=="Pracownik naukowy"
replace employment_role = "Skilled labourer" if q236=="Facharbeiter."
replace employment_role = "Skilled labourer" if q236=="Trabajador/a cualificado/a"
replace employment_role = "Skilled labourer" if q236=="Wykwalifikowany pracownik fizyczny"
replace employment_role = "Consultant" if q236=="Consulting."
replace employment_role = "Consultant" if q236=="Consultor/a"
replace employment_role = "Consultant" if q236=="Konsultant"
replace employment_role = "Temporary employee" if q236=="Leiharbeit."
replace employment_role = "Temporary employee" if q236=="Empleado/a temporal"
replace employment_role = "Temporary employee" if q236=="Pracownik tymczasowy"
replace employment_role = "Trainee" if q236=="Ausbildung."
replace employment_role = "Trainee" if q236=="Aprendiz"
replace employment_role = "Trainee" if q236=="StaÅ¼ysta/praktykant"
replace employment_role = "Other" if q236=="Sonstige."
replace employment_role = "Other" if q236=="Otro"
replace employment_role = "Other" if q236=="Inna"

gen sector="Uknown"
replace sector= "Agriculture, forestry and fishing" if sector_q=="La agricultura, la silvicultura y la pesca"
replace sector= "Agriculture, forestry and fishing" if sector_q=="Landwirtschaft, Forstwirtschaft und Fischerei"
replace sector= "Agriculture, forestry and fishing" if sector_q=="Rolnictwo, leśnictwo, łowiectwo i rybactwo"
replace sector= "Mining and quarrying" if sector_q=="Minas y canteras"
replace sector= "Mining and quarrying" if sector_q=="Bergbau"
replace sector= "Mining and quarrying" if sector_q=="Górnictwo i wydobywanie"
replace sector= "Manufacturing" if sector_q=="Fabricación"
replace sector= "Manufacturing" if sector_q=="Verarbeitendes Gewerbe"
replace sector= "Manufacturing" if sector_q=="Przetwórstwo przemysłowe"
replace sector= "Electricity, gas, steam and air conditioning supply" if sector_q=="Suministro de electricidad, gas, vapor y aire acondicionado"
replace sector= "Electricity, gas, steam and air conditioning supply" if sector_q=="Energieversorgung"
replace sector= "Electricity, gas, steam and air conditioning supply" if sector_q== "Wytwarzanie i zaopatrywanie w energię elektryczną, gaz, parę wodną i powietrze do układów klimatyzacyjnych"
replace sector= "Water supply; sewerage, waste management and remediation activities" if sector_q=="Suministro de agua; actividades de saneamiento, gestión de residuos y remediación"
replace sector= "Water supply; sewerage, waste management and remediation activities" if sector_q=="Wasserversorgung; Abwasserentsorgung und Abfallmanagement"
replace sector= "Water supply; sewerage, waste management and remediation activities" if sector_q=="Dostawa wody, gospodarowanie ściekami i odpadami oraz działalność związana z rekultywacją"
replace sector= "Construction" if sector_q=="Construcción"
replace sector= "Construction" if sector_q=="Baugewerbe"
replace sector= "Construction" if sector_q=="Budownictwo"
replace sector= "Wholesale and retail trade; repair of motor vehicles and motorcycles" if sector_q=="Comercio mayorista y minorista; reparación de vehículos de motor y motocicletas"
replace sector= "Wholesale and retail trade; repair of motor vehicles and motorcycles" if sector_q=="Groß- und Einzelhandel; Reparatur von Kraftfahrzeugen und Motorrädern"
replace sector= "Wholesale and retail trade; repair of motor vehicles and motorcycles" if sector_q=="Handel hurtowy i detaliczny; naprawa pojazdów samochodowych i motocykli"
replace sector= "Transportation and storage" if sector_q=="Transporte y almacenamiento"
replace sector= "Transportation and storage" if sector_q=="Transport und Logistik"
replace sector= "Transportation and storage" if sector_q=="Transport i gospodarka magazynowa"
replace sector= "Accommodation and food services activities" if sector_q=="Actividades de alojamiento y hostelería"
replace sector= "Accommodation and food services activities" if sector_q=="Hotel und Gastgewerbe/Gastronomie"
replace sector= "Accommodation and food services activities" if sector_q=="Działalność związana z zakwaterowaniem i usługami gastronomicznymi"
replace sector= "Information and communication" if sector_q=="Información y comunicación"
replace sector= "Information and communication" if sector_q=="Informations- und Kommunikationstechnologie"
replace sector= "Information and communication" if sector_q=="Informacja i komunikacja"
replace sector= "Financial and insurance activities" if sector_q=="Actividades financieras y de seguros"
replace sector= "Financial and insurance activities" if sector_q=="Finanz- und Versicherungswesen"
replace sector= "Financial and insurance activities" if sector_q=="Działalność finansowa i ubezpieczeniowa"
replace sector= "Real estate activities" if sector_q=="Actividades inmobiliarias"
replace sector= "Real estate activities" if sector_q=="Immobilienwesen"
replace sector= "Real estate activities" if sector_q=="Działalność związana z obsługą rynku nieruchomości"
replace sector= "Professional, scientific and technical activities" if sector_q=="Actividades profesionales, científicas y técnicas"
replace sector= "Professional, scientific and technical activities" if sector_q=="Freiberufliche, wissenschaftliche und technische Tätigkeiten"
replace sector= "Professional, scientific and technical activities" if sector_q=="Działalność profesjonalna, naukowa i techniczna"
replace sector= "Administrative and support service activities" if sector_q=="Actividades administrativas y de servicios de apoyo"
replace sector= "Administrative and support service activities" if sector_q=="Erbringung von sonstigen wirtschaftlichen Dienstleistungen"
replace sector= "Administrative and support service activities" if sector_q=="Działalność w zakresie usług administrowania i działalność wspierająca"
replace sector= "Public administration and defence; compulsory social security" if sector_q=="Administración pública y defensa"
replace sector= "Public administration and defence; compulsory social security" if sector_q=="Öffentliche Verwaltung und Verteidigung"
replace sector= "Public administration and defence; compulsory social security" if sector_q=="Administracja publiczna i obrona narodowa; obowiązkowe zabezpieczenia społeczne"
replace sector= "Education" if sector_q=="Educación"
replace sector= "Education" if sector_q=="Erziehung und Bildung"
replace sector= "Education" if sector_q=="Edukacja"
replace sector= "Human health and social work activities" if sector_q=="Actividades de salud y trabajo social"
replace sector= "Human health and social work activities" if sector_q=="Gesundheits- und Sozialwesen"
replace sector= "Human health and social work activities" if sector_q=="Opieka zdrowotna i pomoc społeczna"
replace sector= "Arts, entertainment and recreation" if sector_q=="Arte, entretenimiento y recreación"
replace sector= "Arts, entertainment and recreation" if sector_q=="Kunst und Unterhaltung"
replace sector= "Arts, entertainment and recreation" if sector_q=="Działalność związana z kulturą, rozrywką i rekreacją"
replace sector= "Other service activities" if sector_q=="Otras actividades de servicios"
replace sector= "Other service activities" if sector_q=="Sonstige Dienstleistungen"
replace sector= "Other service activities" if sector_q=="Pozostała działalność usługowa"
replace sector= "Activities of households as employers; undifferentiated goods- and services-producing activities of households for own use" if sector_q=="Actividades de los hogares como empleadores; actividades indiferenciadas de producción de bienes y servicios de los hogares para uso propio"
replace sector= "Activities of households as employers; undifferentiated goods- and services-producing activities of households for own use" if sector_q=="Hauswirtschaft/Private Haushalte"
replace sector= "Activities of households as employers; undifferentiated goods- and services-producing activities of households for own use" if sector_q=="Gospodarstwa domowe zatrudniające pracowników; gospodarstwa domowe produkujące wyroby i świadczące usługi na własne potrzeby"
replace sector= "Activities of extraterritorial organisations and bodies" if sector_q=="Actividades de organismos y organizaciones extraterritoriales"
replace sector= "Activities of extraterritorial organisations and bodies" if sector_q=="Aktivitäten von extraterritorialen Organisationen und Körperschaften"
replace sector= "Activities of extraterritorial organisations and bodies" if sector_q=="Organizacje i zespoły eksterytorialne"
replace sector= "Other sector" if sector_q=="Otro sector"
replace sector= "Other sector" if sector_q=="Anderer Bereich"
replace sector= "Other sector" if sector_q=="Inna branża"

gen company_size = ""
replace company_size = "1-9 employees" if q240=="1-9 Mitarbeiter"
replace company_size = "1-9 employees" if q240=="1-9 empleados/as."
replace company_size = "1-9 employees" if q240=="1-9 pracownikÃ³w"
replace company_size = "10-49 employees" if q240=="10-49 Mitarbeiter"
replace company_size = "10-49 employees" if q240=="10-49 empleados/as."
replace company_size = "10-49 employees" if q240=="10-49 pracownikÃ³w"
replace company_size = "50-249 employees" if q240=="50-249 Mitarbeiter"
replace company_size = "50-249 employees" if q240=="50-249 empleados/as."
replace company_size = "50-249 employees" if q240=="50-249 pracownikÃ³w"
replace company_size = "250+ employees" if q240=="250+ Mitarbeiter"
replace company_size = "250+ employees" if q240=="250+ empleados/as."
replace company_size = "250+ employees" if q240=="250+ pracownikÃ³w"
replace company_size = "Self-employed" if q240==""

*Create demographics
gen children_in_hh = .
replace children_in_hh = 0 if q232=="Brak"
replace children_in_hh = 0 if q232=="Keine"
replace children_in_hh = 0 if q232=="Ninguno/a."
replace children_in_hh = 1 if q232=="1"
replace children_in_hh = 2 if q232=="2"
replace children_in_hh = 3 if q232=="3"
replace children_in_hh = 4 if q232=="4 lub wiÄcej"
replace children_in_hh = 4 if q232=="4 o mÃ¡s"
replace children_in_hh = 4 if q232=="4 oder mehr"
label variable children_in_hh "Number of children under 16 in household"
label define children_in_hh 0 "0" 1 "1" 2 "2" 3 "3" 4 "4 or more"
label values children_in_hh children_in_hh

*Create variable about taking part in a similar study before
gen similar_study = 0
replace similar_study = 1 if q241=="Ja"
replace similar_study = 1 if q241=="Tak"
replace similar_study = 1 if q241=="SÃ­"

*Prepare data for merge by re-lableing variables
rename qualtricstimer_st_firstclick qtimer1
rename qualtricstimer_st_lastclick qtimer2
rename qualtricstimer_st_pagesubmit qqtimer3
rename qualtricstimer_st_clickcount qtimer4
rename qualtricstimer_mtc_firstclick qtimer5
rename qualtricstimer_mtc_lastclick qtimer6
rename qualtricstimer_mtc_pagesubmit qtimer7
rename qualtricstimer_mtc_clickcount qtimer8
rename qualtricstimer_mtm_firstclick qtimer9
rename qualtricstimer_mtm_lastclick qtimer10
rename qualtricstimer_mtm_pagesubmit qtimer11
rename qualtricstimer_mtm_clickcount qtimer12
rename emp_belief_women_screening emp_belief_w_screening
rename emp_belief_men_screening emp_belief_m_screening
rename belief_employer_same_gender belief_emplyr_s_g
rename women_better_discrimination w_better_discr 
rename men_better_discrimination m_better_discr 

foreach x of var * { 
	rename `x' emplye_`x' 
} 

rename emplye_employer_responseid employer_responseid

*Save data
save "employee_full_final", replace

























































































